CREATE TABLE address_book (
  customers_id mediumint(9) NOT NULL default '0',
  address_book_id smallint(6) NOT NULL default '1',
  entry_company varchar(32) default NULL,
  entry_firstname varchar(32) default NULL,
  entry_lastname varchar(32) default NULL,
  entry_street_address varchar(64) default NULL,
  entry_street_address_2 varchar(64) default NULL,
  entry_postcode varchar(10) default NULL,
  entry_city varchar(32) default NULL,
  entry_state varchar(32) default NULL,
  entry_country_id mediumint(9) default '0',
  entry_zone_id mediumint(9) default '0',
  PRIMARY KEY  (customers_id,address_book_id)
) TYPE=MyISAM;

CREATE TABLE admin_users (
  admin_user_id smallint(6) NOT NULL auto_increment,
  username varchar(32) default 'unknown',
  password varchar(32) default NULL,
  permissions mediumint(9) default '0',
  PRIMARY KEY  (admin_user_id),
  KEY shop_permissions (admin_user_id,permissions)
) TYPE=MyISAM;

CREATE TABLE affiliates (
  affiliates_id smallint(6) NOT NULL auto_increment,
  name varchar(64) default NULL,
  link_code varchar(16) default NULL,
  image varchar(64) default NULL,
  owner varchar(32) default NULL,
  address_phone text,
  country mediumint(9) default '0',
  zone varchar(5) default NULL,
  postal varchar(10) default NULL,
  email varchar(64) default NULL,
  introduction_id mediumint(9) default '1',
  PRIMARY KEY  (affiliates_id),
  KEY shop_introduction (introduction_id)
) TYPE=MyISAM;

CREATE TABLE affiliates_description (
  affiliates_description_id mediumint(9) NOT NULL auto_increment,
  language_id smallint(6) NOT NULL default '0',
  name varchar(64) default NULL,
  introduction text NOT NULL,
  PRIMARY KEY  (affiliates_description_id,language_id)
) TYPE=MyISAM;

CREATE TABLE categories (
  categories_id mediumint(9) NOT NULL auto_increment,
  categories_image varchar(64) default NULL,
  categories_code varchar(64) default NULL,
  parent_id mediumint(9) default '0',
  sort_order smallint(6) default '1',
  date_added datetime default '0000-00-00 00:00:00',
  last_modified datetime default '0000-00-00 00:00:00',
  categories_status smallint(6) default '1',
  last_updater varchar(32) default 'Unknown',
  PRIMARY KEY  (categories_id),
  KEY shop_status (categories_status,categories_id),
  KEY shop_parent (parent_id,categories_id),
  KEY shop_sort (sort_order,categories_id)
) TYPE=MyISAM;

CREATE TABLE categories_description (
  categories_id mediumint(9) NOT NULL default '0',
  language_id smallint(6) NOT NULL default '0',
  categories_name varchar(64) default NULL,
  categories_display_text text,
  meta_title text,
  meta_keywords text,
  meta_description text,
  PRIMARY KEY  (categories_id,language_id),
  KEY shop_name (categories_name)
) TYPE=MyISAM;

CREATE TABLE configuration (
  configuration_id mediumint(9) NOT NULL auto_increment,
  configuration_title varchar(64) default NULL,
  configuration_key varchar(64) default 'NONE',
  configuration_value varchar(255) default NULL,
  configuration_description varchar(255) default NULL,
  configuration_group_id smallint(6) default '0',
  sort_order smallint(6) default '1',
  last_modified datetime default '0000-00-00 00:00:00',
  date_added datetime default '0000-00-00 00:00:00',
  use_function varchar(255) default NULL,
  set_function varchar(255) default NULL,
  PRIMARY KEY  (configuration_id,configuration_key),
  KEY shop_sort (configuration_group_id,sort_order),
  KEY shop_value (configuration_key,configuration_value),
  KEY shop_config_group (configuration_group_id)
) TYPE=MyISAM;

CREATE TABLE countries (
  countries_id smallint(6) NOT NULL auto_increment,
  countries_name varchar(64) default NULL,
  countries_iso_code_2 char(2) default NULL,
  countries_iso_code_3 char(3) default NULL,
  address_format_id smallint(6) default '2',
  continent smallint(6) default '0',
  PRIMARY KEY  (countries_id),
  KEY shop_name (countries_name,countries_id),
  KEY shop_iso3 (countries_iso_code_2,countries_id)
) TYPE=MyISAM;

CREATE TABLE coupons (
  coupons_id mediumint(9) NOT NULL auto_increment,
  coupons_code varchar(32) default '0',
  coupon_type smallint(6) default '1',
  amount varchar(11) default NULL,
  over_amount varchar(11) default NULL,
  categories_id mediumint(9) default '0',
  manufacturers_id mediumint(9) default '0',
  products_id mediumint(9) default '0',
  max_usage smallint(6) default NULL,
  coupons_date_added datetime default '0000-00-00 00:00:00',
  coupons_last_modified datetime default '0000-00-00 00:00:00',
  expires_date datetime default '0000-00-00 00:00:00',
  PRIMARY KEY  (coupons_id),
  KEY shop_type (coupon_type,coupons_id)
) TYPE=MyISAM;

CREATE TABLE coupons_to_customers (
  coupons_id mediumint(9) NOT NULL auto_increment,
  customers_id mediumint(9) NOT NULL default '0',
  coupon_usage smallint(6) default NULL,
  PRIMARY KEY  (coupons_id,customers_id)
) TYPE=MyISAM;

CREATE TABLE currencies (
  currencies_id smallint(6) NOT NULL auto_increment,
  title varchar(32) default NULL,
  code char(3) default NULL,
  symbol_left varchar(12) default NULL,
  symbol_right varchar(12) default NULL,
  decimal_point char(1) default NULL,
  thousands_point char(1) default NULL,
  decimal_places tinyint(4) default NULL,
  value decimal(13,8) default NULL,
  last_updated datetime default '0000-00-00 00:00:00',
  PRIMARY KEY  (currencies_id)
) TYPE=MyISAM;

CREATE TABLE customer_options (
  customer_options_id mediumint(8) unsigned NOT NULL auto_increment,
  products_id mediumint(9) NOT NULL default '0',
  customer_options_options_id mediumint(8) unsigned NOT NULL default '0',
  options_type smallint(6) default '1',
  locx smallint(6) default '0',
  locy smallint(6) default '0',
  PRIMARY KEY  (customer_options_id),
  KEY shop_products (products_id,customer_options_id),
  KEY shop_options_options (customer_options_options_id,customer_options_id)
) TYPE=MyISAM;

CREATE TABLE customer_options_options (
  customer_options_options_id mediumint(8) unsigned NOT NULL auto_increment,
  language_id smallint(6) NOT NULL default '0',
  customer_options_options_name varchar(64) default NULL,
  options_button varchar(64) default NULL,
  PRIMARY KEY  (customer_options_options_id,language_id)
) TYPE=MyISAM;

CREATE TABLE customers (
  customers_id mediumint(9) NOT NULL auto_increment,
  customers_firstname varchar(64) NOT NULL,
  customers_lastname varchar(64) NOT NULL,
  customers_email_address text NOT NULL,
  customers_email_address_flag smallint(6) default '0',
  customers_default_address_id smallint(6) default '2',
  customers_telephone varchar(32) default NULL,
  customers_fax varchar(32) default NULL,
  customers_password varchar(40) default NULL,
  customers_resale_number varchar(16) default NULL,
  home_category mediumint(9) default '0',
  customers_code varchar(16) default NULL,
  customers_default_coupon varchar(32) default '0',
  affiliate varchar(16) default 'my_store',
  PRIMARY KEY  (customers_id),
  KEY shop_affiliate (affiliate,customers_id)
) TYPE=MyISAM;

CREATE TABLE customers_info (
  customers_info_id mediumint(9) NOT NULL default '0',
  customers_info_date_of_last_logon datetime default '0000-00-00 00:00:00',
  customers_info_number_of_logons smallint(6) default NULL,
  customers_info_date_account_created datetime default '0000-00-00 00:00:00',
  customers_info_date_account_last_modified datetime default '0000-00-00 00:00:00',
  PRIMARY KEY  (customers_info_id)
) TYPE=MyISAM;

CREATE TABLE features (
  features_id mediumint(9) NOT NULL auto_increment,
  products_id mediumint(9) NOT NULL default '0',
  features_date_added datetime default '0000-00-00 00:00:00',
  features_last_modified datetime default '0000-00-00 00:00:00',
  expires_date datetime default '0000-00-00 00:00:00',
  PRIMARY KEY  (features_id),
  KEY shop_products (products_id,features_id)
) TYPE=MyISAM;

CREATE TABLE geo_zones (
  geo_zone_id smallint(6) NOT NULL auto_increment,
  geo_zone_name varchar(32) default NULL,
  geo_zone_description varchar(64) default NULL,
  last_modified datetime default '0000-00-00 00:00:00',
  date_added datetime default '0000-00-00 00:00:00',
  PRIMARY KEY  (geo_zone_id)
) TYPE=MyISAM;

CREATE TABLE information_documents (
  information_document_id mediumint(9) NOT NULL auto_increment,
  information_panel_id smallint(6) NOT NULL default '0',
  language_id smallint(6) NOT NULL default '0',
  name varchar(64) default NULL,
  body text,
  status smallint(6) default '1',
  PRIMARY KEY  (information_document_id,language_id),
  KEY shop_panel (language_id,information_panel_id,information_document_id)
) TYPE=MyISAM;

CREATE TABLE information_panels (
  information_panel_id smallint(6) NOT NULL auto_increment,
  language_id smallint(6) NOT NULL default '0',
  name varchar(64) default NULL,
  tag varchar(64) default NULL,
  PRIMARY KEY  (information_panel_id,language_id)
) TYPE=MyISAM;

CREATE TABLE languages (
  languages_id smallint(6) NOT NULL auto_increment,
  name varchar(32) default NULL,
  code char(2) default NULL,
  image varchar(64) default NULL,
  PRIMARY KEY  (languages_id)
) TYPE=MyISAM;

CREATE TABLE manufacturers (
  manufacturers_id mediumint(9) NOT NULL auto_increment,
  manufacturers_name varchar(32) default NULL,
  manufacturers_email varchar(64) default NULL,
  manufacturers_image varchar(64) default NULL,
  manufacturers_password varchar(48) default NULL,
  manufacturers_url text,
  date_added datetime default '0000-00-00 00:00:00',
  last_modified datetime default '0000-00-00 00:00:00',
  PRIMARY KEY  (manufacturers_id)
) TYPE=MyISAM;

CREATE TABLE mshox_artists (
  aid mediumint(9) NOT NULL auto_increment,
  artist varchar(32) default NULL,
  artist_website text,
  artist_pic text,
  artist_bio text,
  language_id smallint(6) NOT NULL default '0',
  artist_id mediumint(9) NOT NULL default '0',
  PRIMARY KEY  (aid)
) TYPE=MyISAM;

CREATE TABLE mshox_product_media (
  product_media_id mediumint(8) unsigned NOT NULL auto_increment,
  product_id mediumint(9) NOT NULL default '0',
  track_number smallint(6) default '0',
  track_name varchar(64) default '',
  track_filename varchar(96) default '',
  track_format char(2) default 'NO',
  PRIMARY KEY  (product_media_id),
  KEY shop_products (product_id,product_media_id)
) TYPE=MyISAM;

CREATE TABLE mshox_products (
  album_id mediumint(9) NOT NULL auto_increment,
  artist_id mediumint(9) NOT NULL default '0',
  product_id mediumint(9) NOT NULL default '0',
  PRIMARY KEY  (album_id),
  KEY shop_artists (artist_id,album_id),
  KEY shop_products (product_id,album_id)
) TYPE=MyISAM;

CREATE TABLE mshox_tour_dates (
  tour_date_id mediumint(9) NOT NULL auto_increment,
  artist_id mediumint(9) NOT NULL default '0',
  venue varchar(32) default '',
  venue_url text,
  venue_location text,
  venue_map_url text,
  tour_date datetime default '0000-00-00 00:00:00',
  PRIMARY KEY  (tour_date_id),
  KEY shop_artists (artist_id,tour_date_id)
) TYPE=MyISAM;

CREATE TABLE orders (
  orders_id mediumint(8) unsigned NOT NULL auto_increment,
  customers_id mediumint(9) NOT NULL default '0',
  customers_name varchar(64) default NULL,
  customers_company varchar(64) default NULL,
  customers_street_address varchar(64) default NULL,
  customers_street_address_2 varchar(64) default NULL,
  customers_city varchar(32) default NULL,
  customers_postcode varchar(10) default NULL,
  customers_state varchar(32) default NULL,
  customers_country varchar(48) default NULL,
  customers_telephone varchar(32) default NULL,
  customers_email_address varchar(96) default NULL,
  customers_address_format_id smallint(6) default '2',
  delivery_name varchar(64) default NULL,
  delivery_company varchar(64) default NULL,
  delivery_street_address varchar(64) default NULL,
  delivery_street_address_2 varchar(64) default NULL,
  delivery_city varchar(32) default NULL,
  delivery_postcode varchar(10) default NULL,
  delivery_state varchar(32) default NULL,
  delivery_country varchar(48) default NULL,
  delivery_address_format_id smallint(6) default '2',
  payment_method varchar(32) default NULL,
  cc_type varchar(20) default NULL,
  cc_owner varchar(64) default NULL,
  cc_number varchar(32) default NULL,
  cc_expires varchar(4) default NULL,
  cc_code varchar(6) default NULL,
  cc_approval varchar(12) default NULL,
  po_number varchar(32) default NULL,
  last_modified datetime default '0000-00-00 00:00:00',
  date_purchased datetime default '0000-00-00 00:00:00',
  orders_status smallint(6) default '1',
  orders_date_finished datetime default '0000-00-00 00:00:00',
  comments text,
  currency char(3) default NULL,
  currency_value decimal(7,3) default NULL,
  referer varchar(48) default 'Unknown',
  affiliate varchar(48) default 'my_store',
  last_updater varchar(32) default 'Unknown',
  shipping_method varchar(64) default NULL,
  PRIMARY KEY  (orders_id),
  KEY shop_customers (customers_id,orders_id)
) TYPE=MyISAM;

CREATE TABLE orders_coupons (
  orders_coupons_id int(11) unsigned NOT NULL auto_increment,
  coupons_id mediumint(9) NOT NULL default '0',
  orders_id mediumint(8) unsigned NOT NULL default '0',
  coupons_code varchar(32) default '0',
  coupon_type smallint(6) default '1',
  amount varchar(11) default NULL,
  over_amount varchar(11) default NULL,
  categories_id mediumint(9) default '0',
  manufacturers_id mediumint(9) default '0',
  products_id mediumint(9) default '0',
  max_usage smallint(6) default NULL,
  coupons_date_added datetime default '0000-00-00 00:00:00',
  coupons_last_modified datetime default '0000-00-00 00:00:00',
  expires_date datetime default '0000-00-00 00:00:00',
  PRIMARY KEY  (orders_coupons_id),
  KEY orders_id (orders_id)
) TYPE=MyISAM;

CREATE TABLE orders_customer_options (
  orders_customer_options_id int(11) NOT NULL auto_increment,
  orders_id mediumint(8) unsigned NOT NULL default '0',
  products_id mediumint(9) NOT NULL default '0',
  customer_options varchar(64) default NULL,
  customer_options_value text,
  customer_options_type smallint(6) default '1',
  customer_options_id mediumint(8) unsigned NOT NULL default '0',
  locx smallint(6) default '0',
  locy smallint(6) default '0',
  PRIMARY KEY  (orders_id,orders_customer_options_id),
  KEY shop_products (products_id,orders_customer_options_id)
) TYPE=MyISAM;

CREATE TABLE orders_products (
  orders_products_id int(11) NOT NULL auto_increment,
  orders_id mediumint(8) unsigned NOT NULL default '0',
  products_id mediumint(9) NOT NULL default '0',
  products_model varchar(64) default NULL,
  products_name varchar(96) default '',
  products_sku varchar(64) default '',
  products_price decimal(12,3) default '0.000',
  products_cost decimal(12,3) default '0.000',
  final_price decimal(12,3) default '0.000',
  products_tax decimal(7,3) default '0.000',
  products_quantity mediumint(9) default '1',
  products_image varchar(96) default '',
  serial_number text,
  coupon_amount decimal(12,3) default '0.000',
  PRIMARY KEY  (orders_id,orders_products_id),
  KEY shop_products (products_id,orders_products_id)
) TYPE=MyISAM;

CREATE TABLE orders_products_attributes (
  orders_products_attributes_id int(11) NOT NULL auto_increment,
  orders_id mediumint(8) unsigned NOT NULL default '0',
  orders_products_id int(11) NOT NULL default '0',
  products_options varchar(32) default NULL,
  products_options_values varchar(32) default NULL,
  options_values_price decimal(12,3) default '0.000',
  price_prefix char(1) default NULL,
  products_options_image varchar(48) default NULL,
  products_options_id mediumint(8) unsigned NOT NULL default '0',
  products_options_values_id mediumint(8) unsigned NOT NULL default '0',
  PRIMARY KEY  (orders_id,orders_products_attributes_id),
  KEY shop_orders_products (orders_products_id,orders_products_attributes_id)
) TYPE=MyISAM;

CREATE TABLE orders_products_download (
  orders_products_download_id mediumint(8) unsigned NOT NULL auto_increment,
  orders_id mediumint(8) unsigned NOT NULL default '0',
  orders_products_id int(11) NOT NULL default '0',
  orders_products_filename varchar(96) default NULL,
  download_maxdays smallint(6) default NULL,
  download_count smallint(6) default NULL,
  PRIMARY KEY  (orders_id,orders_products_download_id)
) TYPE=MyISAM;

CREATE TABLE orders_status_history (
  orders_status_history_id mediumint(8) unsigned NOT NULL auto_increment,
  orders_id mediumint(8) unsigned NOT NULL default '0',
  new_value tinyint(4) default NULL,
  old_value tinyint(4) default NULL,
  date_added datetime default '0000-00-00 00:00:00',
  tracking_number varchar(32) default NULL,
  tracking_number_type smallint(6) default '0',
  customer_notified tinyint(4) default '0',
  PRIMARY KEY  (orders_id,orders_status_history_id),
  KEY shop_status (new_value,orders_status_history_id)
) TYPE=MyISAM;

CREATE TABLE orders_status_values (
  status_id tinyint(3) unsigned NOT NULL auto_increment,
  language_id tinyint(3) unsigned NOT NULL default '0',
  status_name varchar(255) NOT NULL default '',
  status_type enum('new','processing','intransit','delivered','terminated') NOT NULL default 'new',
  is_active enum('0','1') NOT NULL default '0',
  sort_order tinyint(3) unsigned NOT NULL default '0',
  PRIMARY KEY  (status_id,language_id)
) TYPE=MyISAM COMMENT='Order Status Values';

CREATE TABLE orders_total (
  orders_total_id mediumint(8) unsigned NOT NULL auto_increment,
  orders_id mediumint(8) unsigned NOT NULL default '0',
  title varchar(16) default NULL,
  text varchar(64) default NULL,
  value decimal(13,3) default '0.000',
  class varchar(32) default NULL,
  PRIMARY KEY  (orders_id,orders_total_id)
) TYPE=MyISAM;

CREATE TABLE products (
  products_id mediumint(9) NOT NULL auto_increment,
  products_quantity mediumint(9) default '1',
  products_model varchar(64) default NULL,
  products_image varchar(96) default NULL,
  products_call_for_price enum('0','1') default '0',
  products_turnoff_sold enum('0','1') default '0',
  products_price varchar(120) default '',
  products_cost varchar(120) default '',
  products_date_added datetime default '0000-00-00 00:00:00',
  products_last_modified datetime default '0000-00-00 00:00:00',
  products_date_available datetime default '0000-00-00 00:00:00',
  products_weight decimal(5,2) default '0.00',
  products_status smallint(6) default '1',
  products_tax_class_id smallint(6) default '0',
  products_sku varchar(64) default NULL,
  products_free_shipping enum('0','1') NOT NULL default '0',
  manufacturers_id mediumint(9) default '0',
  products_ordered mediumint(8) unsigned default '0',
  last_updater varchar(32) default 'Unknown',
  products_thumb varchar(64) default NULL,
  PRIMARY KEY  (products_id),
  KEY shop_status (products_status,products_id)
) TYPE=MyISAM;

CREATE TABLE products_attributes (
  products_attributes_id mediumint(8) unsigned auto_increment,
  products_id mediumint(9) NOT NULL default '0',
  options_id mediumint(9) NOT NULL default '0',
  options_values_id mediumint(9) NOT NULL default '0',
  options_values_price decimal(12,3) default '0.000',
  price_prefix char(1) default NULL,
  options_weight decimal(5,2) unsigned NOT NULL default '0.00',
  weight_prefix char(1) NOT NULL default '',
  attribute_image varchar(64) default NULL,
  is_default smallint(6) default '0',
  options_model varchar(64) default NULL,
  options_sku varchar(64) default NULL,
  locx smallint(6) default '0',
  locy smallint(6) default '0',
  size tinyint(4) default NULL,
  PRIMARY KEY  (products_attributes_id)
) TYPE=MyISAM;

CREATE TABLE products_attributes_download (
  products_attributes_id mediumint(8) unsigned NOT NULL auto_increment,
  products_attributes_filename varchar(96) default NULL,
  products_attributes_maxdays smallint(6) default '0',
  products_attributes_maxcount smallint(6) default '0',
  PRIMARY KEY  (products_attributes_id)
) TYPE=MyISAM;

CREATE TABLE products_description (
  products_id mediumint(9) NOT NULL default '0',
  language_id smallint(6) NOT NULL default '0',
  products_mshox_status smallint(6) default '0',
  products_name varchar(64) default NULL,
  products_description text,
  products_url text,
  products_technical text,
  products_viewed mediumint(9) default '0',
  meta_title text,
  meta_keywords text,
  meta_description text,
  PRIMARY KEY  (products_id,language_id),
  KEY shop_name (products_name,products_id)
) TYPE=MyISAM;

CREATE TABLE products_options (
  products_options_id mediumint(9) NOT NULL auto_increment,
  language_id smallint(6) NOT NULL default '0',
  products_options_name varchar(64) default NULL,
  options_mode tinyint(4) default NULL,
  options_button varchar(64) default NULL,
  PRIMARY KEY  (products_options_id,language_id),
  KEY shop_language (language_id,products_options_id),
  KEY shop_name (products_options_name,products_options_id)
) TYPE=MyISAM;

CREATE TABLE products_options_values (
  products_options_values_id mediumint(9) NOT NULL auto_increment,
  products_options_id smallint(5) unsigned NOT NULL default '0',
  language_id smallint(6) NOT NULL default '0',
  products_options_values_name varchar(64) default NULL,
  PRIMARY KEY  (products_options_values_id,language_id),
  KEY shop_language (language_id,products_options_values_id),
  KEY shop_name (products_options_values_name,products_options_values_id)
) TYPE=MyISAM;

CREATE TABLE products_to_categories (
  products_id mediumint(9) NOT NULL default '0',
  categories_id mediumint(9) NOT NULL default '0',
  sort_order smallint(6) default '1',
  PRIMARY KEY  (categories_id,products_id),
  KEY shop_sort (sort_order,products_id)
) TYPE=MyISAM;

CREATE TABLE sessions (
  session_id varchar(32) NOT NULL default '',
  customers_id mediumint(9) NOT NULL default '0',
  session_created int(11) default '0',
  session_active int(11) default '0',
  session_counter int(11) default '0',
  session_data longtext,
  PRIMARY KEY  (session_id)
) TYPE=MyISAM;

CREATE TABLE sn_products (
  sn_product_id mediumint(9) NOT NULL auto_increment,
  product_id mediumint(9) NOT NULL default '0',
  sn_eval text,
  PRIMARY KEY  (sn_product_id),
  KEY shop_products (product_id,sn_product_id)
) TYPE=MyISAM;

CREATE TABLE specials (
  specials_id mediumint(9) NOT NULL auto_increment,
  products_id mediumint(9) NOT NULL default '0',
  specials_new_products_price char(120) default '',
  specials_date_added datetime default '0000-00-00 00:00:00',
  specials_last_modified datetime default '0000-00-00 00:00:00',
  expires_date datetime default '0000-00-00 00:00:00',
  date_status_change datetime default '0000-00-00 00:00:00',
  status smallint(6) default '0',
  PRIMARY KEY  (specials_id),
  KEY shop_products (products_id,specials_id)
) TYPE=MyISAM;

CREATE TABLE tax_class (
  tax_class_id smallint(6) NOT NULL auto_increment,
  tax_class_title varchar(32) default NULL,
  tax_class_description varchar(64) default NULL,
  last_modified datetime default '0000-00-00 00:00:00',
  date_added datetime default '0000-00-00 00:00:00',
  PRIMARY KEY  (tax_class_id),
  KEY shop_name (tax_class_title,tax_class_id)
) TYPE=MyISAM;

CREATE TABLE tax_rates (
  tax_rates_id smallint(6) NOT NULL auto_increment,
  tax_zone_id smallint(6) NOT NULL default '0',
  tax_class_id smallint(6) NOT NULL default '0',
  tax_rate decimal(7,3) default '0.000',
  tax_description varchar(64) default NULL,
  last_modified datetime default '0000-00-00 00:00:00',
  date_added datetime default '0000-00-00 00:00:00',
  PRIMARY KEY  (tax_rates_id),
  KEY shop_classes_zones (tax_class_id,tax_zone_id,tax_rates_id),
  KEY shop_classes (tax_class_id,tax_rates_id),
  KEY shop_zones (tax_zone_id,tax_rates_id)
) TYPE=MyISAM;

CREATE TABLE ups_worldship (
  id int(10) unsigned NOT NULL auto_increment,
  orders_id bigint(20) unsigned NOT NULL default '0',
  date_added timestamp NOT NULL default CURRENT_TIMESTAMP,
  tracking_number varchar(255) NOT NULL default '',
  status_id tinyint(3) NOT NULL default '0',
  void enum('0','1') NOT NULL default '0',
  processed enum('0','1') NOT NULL default '0',
  PRIMARY KEY  (id),
  KEY orders_id (orders_id)
) TYPE=MyISAM;

CREATE TABLE zones (
  zone_id mediumint(9) NOT NULL auto_increment,
  zone_country_id mediumint(9) NOT NULL default '0',
  zone_code varchar(32) default NULL,
  zone_name varchar(32) default NULL,
  PRIMARY KEY  (zone_id),
  KEY shop_name (zone_name),
  KEY shop_code (zone_code,zone_id),
  KEY shop_countries (zone_country_id,zone_id)
) TYPE=MyISAM;

CREATE TABLE zones_to_geo_zones (
  association_id smallint(6) NOT NULL auto_increment,
  zone_country_id mediumint(9) NOT NULL default '0',
  zone_id mediumint(9) NOT NULL default '0',
  geo_zone_id smallint(6) NOT NULL default '0',
  last_modified datetime default '0000-00-00 00:00:00',
  date_added datetime default '0000-00-00 00:00:00',
  PRIMARY KEY  (association_id),
  KEY shop_countries_zones (zone_country_id,zone_id,association_id),
  KEY shop_countries (zone_country_id,association_id),
  KEY shop_zones (zone_id,association_id)
) TYPE=MyISAM;



INSERT INTO admin_users VALUES (1,'admin','fgBv61mVsBMyg',1023);

INSERT INTO affiliates VALUES (1,'My Store','my_store','mystore_logo.gif','Webmaster','123 Test Street\rLos Angeles, CA 90210\rUnited States',223,'12','90210','webmaster@localhost',1);

INSERT INTO affiliates_description VALUES (1,1,'Default','[welcome]');

INSERT INTO configuration VALUES (NULL, 'Serial Number', 'A_SERIAL', NULL, 'eShox Serial Number', 1, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Credit Card Symbols', 'CC_SYMBOLS', '<img src="images/payment/visa.gif"> <img src="images/payment/mastercard.gif"> <img src="images/payment/amex.gif"> <img src="images/payment/discover.gif">', 'HTML for display of credit card symbols.', 1, 9, now(), now(), NULL, 'shop_cfg_textarea(');
INSERT INTO configuration VALUES (NULL, 'Clear Cart After Checkout', 'CLEAR_CART', 'true', 'Clear the shopping cart after checking out (or leave products in cart)', 10, 6, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Calculate Image Size', 'CONFIG_CALCULATE_IMAGE_SIZE', 'true', 'Calculate the size of images?', 4, 7, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Limit store access to "resellers"', 'CONFIG_RESELLER_ACCESS', 'false', 'Limit store access to authorized customers (create customers via "import/export")', 2, 4, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Allow one coupon per order', 'COUPONS_ALLOW_ONE', 'false', 'Only allow one coupon per order. Set to false to allow coupon stacking.', 2, 5, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Debugging', 'DEBUGGING', 'false', 'Display debugging information in store.', 1, 12, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, NULL, 'DEFAULT_AFFILIATE', 'my_store', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, NULL, 'DEFAULT_CURRENCY', 'USD', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, NULL, 'DEFAULT_LANGUAGE', 'en', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Default Order Status For New Orders', 'DEFAULT_ORDERS_STATUS_ID', '1', 'When a new order is created, this order status will be assigned to it.', 6, 0, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Rendezvous / LPR Printing', 'DEFAULT_PRINTER', 'none', 'The printer to which orders should be printed', 1, 9, now(), now(), NULL, 'shop_printer_list(');
INSERT INTO configuration VALUES (NULL, 'Display Cart After Adding Product', 'DISPLAY_CART', 'true', 'Display the shopping cart after adding a product (or return back to their origin)', 10, 6, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'EU VAT Numbers for Tax Exemption', 'DISPLAY_EU_VAT', 'false', 'Allow EU VAT Numbers in Account Info', 10, 5, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Display Prices with Tax (VAT)', 'DISPLAY_PRICE_WITH_TAX', 'false', 'Display product prices with tax included (VAT)', 10, 4, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Display Number of Products in Category', 'DISPLAY_PRODUCTS_IN_CATEGORY', 'false', 'Display the number of products in each category when listing categories', 10, 7, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Navbar Shopping Cart Item Display', 'DISPLAY_SCART_MODEL', 'product names', 'Display small shopping cart items as:', 10, 11, now(), now(), NULL, 'shop_cfg_select_option(array(''product names'', ''product models''),');
INSERT INTO configuration VALUES (NULL, 'Enable file download', 'DOWNLOAD_ENABLED', 'false', 'Enable downloadable products (define in product options)', 2, 1, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Graphical Text Editor', 'TEXT_EDITOR', 'Basic', 'Type of text editor to use when modifying product descriptions, etc', '2', '7', now(), now(), NULL, 'shop_cfg_select_option(array(''None'', ''Basic'', ''Intermediate'', ''Advanced''),');
INSERT INTO configuration VALUES (NULL, 'Google Analytics Account Code', 'GOOGLE_ANALYTICS', '', 'Google Analytics Account Code (format: UA-xxxxx-x)', 2, 8, now(), now(), NULL, '');
INSERT INTO configuration VALUES (NULL, 'Google Analytics Conversion Code', 'GOOGLE_ANALYTICS_CONVERSION', '', 'Google Analytics Conversion Code (numeric)', 2, 9, now(), now(), NULL, '');
INSERT INTO configuration VALUES (NULL , 'Google Base', 'GOOGLE_BASE', 'false', 'Enable Google Base RSS2.0 Data Feed. Point Google to the google_base.xml file in your shop directory. You will need to manually run the google_base.php file to populate the xml file with your product information.', '2', '10', NOW(), NOW(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL , 'Yahoo Analytics Conversion Code', 'YAHOO_ANALYTICS_CONVERSION', '', 'Yahoo Analytics Conversion Code', '2', '11', now(), now(), NULL, '');
INSERT INTO configuration VALUES (NULL, 'Credit Card Number Handling', 'MAIL_CC_HANDLE', 'last 4 digits', 'KEEP: Stores the number in the database.<br />EMAIL: The middle digits are Emailed to the store owner.<br />LAST 4 DIGITS: Only the last 4 digits will be stored in the database.', 1, 8, now(), now(), NULL, 'shop_cfg_select_option(array(''keep'', ''email'', ''last 4 digits''),');
INSERT INTO configuration VALUES (NULL, 'Mail Format', 'MAIL_FORMAT', 'Both', 'The format of Email messages sent from the store', 1, 7, now(), now(), NULL, 'shop_cfg_select_option(array(''Plain Text'', ''HTML'', ''Both''),');
INSERT INTO configuration VALUES (NULL, 'SMTP Mail Servers', 'MAIL_SERVER_ADDR', NULL, 'The domain names or IP addresses of my SMTP mail servers, in this format: user:password#mail.server1.com, user:password#mail.server2.com', 1, 5, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Mail Service', 'MAIL_SERVICE', 'sendmail', 'The type of mail service to use for sending mail', 1, 4, now(), now(), NULL, 'shop_cfg_select_option(array(''sendmail'', ''SMTP''),');
INSERT INTO configuration VALUES (NULL, 'Items/Row', 'MAX_DISPLAY_ITEMS_ROW', '3', 'Number of items to display on each line when viewed in image mode', 8, 12, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Items/Page', 'MAX_DISPLAY_SEARCH_RESULTS', '20', 'Number of items to display on each listing page', 8, 11, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Search Engine Abstract', 'META_ABSTRACT', 'Distributor of Great Products', 'Search engine site abstract', 7, 2, now(), now(), NULL, 'shop_cfg_textarea(');
INSERT INTO configuration VALUES (NULL, 'Search Engine Description', 'META_DESCRIPTION', 'My Store', 'Search engine site description', 7, 3, now(), now(), NULL, 'shop_cfg_textarea(');
INSERT INTO configuration VALUES (NULL, 'Search Engine Keywords', 'META_KEYWORDS', 'Great Products', 'Search engine site keywords and phrases', 7, 1, now(), now(), NULL, 'shop_cfg_textarea(');
INSERT INTO configuration VALUES (NULL, 'Search Engine Robot Mode', 'META_ROBOTS', 'index, follow', 'Search engine site robot indexing mode', 7, 4, now(), now(), NULL, 'shop_cfg_select_option(array(''index, follow'',''noindex, follow'',''index, nofollow'',''noindex, nofollow''),');
INSERT INTO configuration VALUES(NULL, 'Search Engine Friendly URLs', 'MOD_REWRITE', 'false', 'Create search engine friendly URLs, see help on how to implement this feature', 7, 5, NOW(), NOW(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Display Coupon Groups', 'MODULE_ORDER_TOTAL_COUPON_GROUPS', 'false', 'Display coupon groups at checkout?', 6, 1, now(), now(), 'shop_cfg_checkbox_display(', 'shop_cfg_checkbox(');
INSERT INTO configuration VALUES (NULL, NULL, 'MODULE_ORDER_TOTAL_COUPON_STATUS', 'true', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Provide Free Shipping For Orders Made', 'MODULE_ORDER_TOTAL_SHIPPING_DESTINATION', 'national', 'Provide free shipping for orders sent to the following destination.', 6, 3, now(), now(), NULL, 'shop_cfg_select_option(array(''national'', ''international''),');
INSERT INTO configuration VALUES (NULL, 'Allow Free Shipping', 'MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING', 'false', 'Allow free shipping?', 6, 1, now(), now(), 'shop_cfg_checkbox_display(', 'shop_cfg_checkbox(');
INSERT INTO configuration VALUES (NULL, 'Free Shipping For Orders Over', 'MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_OVER', '50', 'Provide free shipping for orders over the set amount.', 6, 2, now(), now(), 'shop_cfg_price_display(', NULL);
INSERT INTO configuration VALUES (NULL, NULL, 'MODULE_ORDER_TOTAL_SHIPPING_STATUS', 'true', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Tax Class', 'MODULE_ORDER_TOTAL_SHIPPING_TAX_CLASS', '0', 'Use the following tax class on the shipping fee.', 6, 4, now(), now(), 'shop_get_tax_class_title', 'shop_cfg_pull_down_tax_classes(');
INSERT INTO configuration VALUES (NULL, NULL, 'MODULE_ORDER_TOTAL_SUBTOTAL_STATUS', 'true', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Customers Tax Location', 'MODULE_ORDER_TOTAL_TAX_ADDRESS_BOOK_ID', 'Billing', 'Which address should be used for tax calculations?', 6, 1, now(), now(), NULL, 'shop_cfg_select_option(array(''Billing'', ''Shipping''),');
INSERT INTO configuration VALUES (NULL, 'Display Tax Groups', 'MODULE_ORDER_TOTAL_TAX_SHOW_GROUPS', 'false', 'Display tax groups at checkout?', 6, 2, now(), now(), 'shop_cfg_checkbox_display(', 'shop_cfg_checkbox(');
INSERT INTO configuration VALUES (NULL, NULL, 'MODULE_ORDER_TOTAL_TAX_STATUS', 'true', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, NULL, 'MODULE_ORDER_TOTAL_TOTAL_STATUS', 'true', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, NULL, 'MODULE_PAYMENT_CC_STATUS', 'true', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, NULL, 'MODULE_PAYMENT_INSTALLED', 'cc.php;moneyorder.php', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, NULL, 'MODULE_PAYMENT_MONEYORDER_STATUS', 'true', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Flat Cost', 'MODULE_SHIPPING_FLAT_COST', '5.00', 'What is the Shipping cost? The Handling fee will also be added.', 6, 2, now(), now(), 'shop_cfg_price_display(', NULL);
INSERT INTO configuration VALUES (NULL, 'Name of flat shipping option', 'MODULE_SHIPPING_FLAT_NAME', 'Flat Rate Shipping', 'The name of the flat shipping option:', 6, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, NULL, 'MODULE_SHIPPING_FLAT_STATUS', 'true', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, NULL, 'MODULE_SHIPPING_INSTALLED', 'flat.php', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, NULL, 'MODULE_SKIN_SELECTED', 'aqua_skin', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, NULL, 'MODULE_THEME_SELECTED', 'aqua_theme', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Music Features', 'MSHOX_STATUS', 'false', 'Enable Music-related functionality', 2, 2, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Navbar Contents Alignment', 'NAVBAR_ALIGNMENT', 'right', 'Align the navbar contents', 10, 9, now(), now(), NULL, 'shop_cfg_select_option(array(''left'', ''center'', ''right''),');
INSERT INTO configuration VALUES (NULL, 'Navbar Language Display Mode', 'NAVBAR_FLAGS', 'small flags', 'Display available languages in the following format', 10, 10, now(), now(), NULL, 'shop_cfg_select_option(array(''flags'', ''small flags'', ''pop-up list''),');
INSERT INTO configuration VALUES (NULL, 'Navbar Headers Alignment', 'NAVBAR_HEADER_ALIGNMENT', 'right', 'Align the navbar headers', 10, 8, now(), now(), NULL, 'shop_cfg_select_option(array(''left'', ''center'', ''right''),');
INSERT INTO configuration VALUES (NULL, 'Navbar Product Image Display', 'NAVBAR_IMAGE_MODE', 'thumbnails', 'Display Specials, New Products and Features using the following product image', 10, 12, now(), now(), NULL, 'shop_cfg_select_option(array(''product images'', ''thumbnails''),');
INSERT INTO configuration VALUES (NULL, 'Product Info Image Height', 'PINFO_IMAGE_HEIGHT', '240', 'The height (in pixels) of product images on product info pages', 4, 2, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Product Info Image Width', 'PINFO_IMAGE_WIDTH', NULL, 'The width (in pixels) of product images on product info pages', 4, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Location of Prev/Next Navigation Bar', 'PREV_NEXT_BAR_LOCATION', 'bottom', 'Sets the location of the Prev/Next Navigation Bar', 8, 10, now(), now(), NULL, 'shop_cfg_select_option(array(''top'', ''bottom'', ''both''),');
INSERT INTO configuration VALUES (NULL, 'Display Buy or Quantity Field', 'PRODUCT_LIST_BUY_NOW', 'none', 'Display buy now buttons or quantity fields when viewed in list mode?', 8, 9, now(), now(), NULL, 'shop_cfg_select_option(array(''none'', ''buy now'', ''quantity fields''),');
INSERT INTO configuration VALUES (NULL, 'Display Product Image', 'PRODUCT_LIST_IMAGE', 'false', 'Display the Product Image when viewed in list mode?', 8, 1, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Display Product Manufaturer Name', 'PRODUCT_LIST_MANUFACTURER', 'false', 'Display the Product Manufacturer Name?', 8, 2, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Display Product Minimum Order Quantity', 'PRODUCT_LIST_MIN_QTY', 'false', 'Display the Product Minimum Order Quantity?', 8, 8, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Display Product Model', 'PRODUCT_LIST_MODEL', 'false', 'Display the Product Model?', 8, 3, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Display Product Name', 'PRODUCT_LIST_NAME', 'true', 'Display the Product Name?', 8, 4, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Display Product Price', 'PRODUCT_LIST_PRICE', 'true', 'Display the Product Price', 8, 5, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Display Product Quantity', 'PRODUCT_LIST_QUANTITY', 'false', 'Display the Product Quantity when viewed in list mode?', 8, 6, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Display Product Weight', 'PRODUCT_LIST_WEIGHT', 'false', 'Display the Product Weight when viewed in list mode?', 8, 7, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Real-time currency rate updates', 'REALTIME_CURRENCY', 'true', 'Enable real-time currency rate conversion (service and availability not guaranteed)', 2, 6, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, NULL, 'REALTIME_CURRENCY_LAST_UPDATE', '0', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Secure HTTPS (SSL) URL', 'SECURE_SERVER_ADDRESS', NULL, 'The full URL of your store via SSL (including https:// - leave blank for none)', 1, 3, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Copy Emails To', 'SEND_EXTRA_ORDER_EMAILS_TO', NULL, 'Send a copy of order Emails to the following Email addresses, in this format: Email@address1, Email@address2', 1, 6, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Server-side Image Scaling', 'SERVER_SIDE_SCALING', 'true', 'Resize images on server (better quality)?', 4, 8, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Session Handler', 'SESSIONS_TYPE', 'MySQL Sessions', 'The storage system to use when saving cart and session/cookie data', 1, 10, now(), now(), NULL, 'shop_cfg_select_option(array(''MySQL Sessions'',''Default Sessions''),');
INSERT INTO configuration VALUES (NULL, 'Session Security', 'SESSION_SECURITY', 'false', 'Increase security by tracking users IP numbers (will not work with some proxies including AOL).', 1, 11, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Handling fee for all packages', 'SHIPPING_HANDLING', '0', 'The handling fee you may charge.', 9, 3, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Insurance fee for all packages', 'SHIPPING_INSURANCE', '0.0%', 'Insurance fee for all packages (percentage of order total)', 9, 4, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Shipping markup/markdown', 'SHIPPING_MARK', '0.0%', 'Shipping price markup or markdown (percentage of shipping cost)', 9, 6, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Packaging weight', 'SHIPPING_PACKWEIGHT', '0', 'Box and packaging weight (lbs) to be added to product weight', 9, 5, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, NULL, 'SHOX_RELEASE', '11', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, NULL, 'SHOX_VERSION', '3900', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'List Image Height', 'SMALL_IMAGE_HEIGHT', '120', 'The height (in pixels) of category and product images in lists', 4, 4, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'List Image Width', 'SMALL_IMAGE_WIDTH', NULL, 'The width (in pixels) of category and product images in lists', 4, 3, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Serial Number Features', 'SN_STATUS', 'false', 'Enable serial number functionality', 2, 3, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, NULL, 'SOFTWARE_UPDATE', '0', NULL, 0, 1, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Allow Purchase', 'STOCK_ALLOW_CHECKOUT', 'true', 'Allow customer to purchase/checkout even if there is insufficient stock', 9, 2, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Check stock level', 'STOCK_CHECK', 'true', 'Check to see if sufficent stock is available', 9, 1, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'List Header Image Height', 'SUBCATEGORY_IMAGE_HEIGHT', NULL, 'The height (in pixels) of category and manufacturer header images in product lists', 4, 6, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'List Header Image Width', 'SUBCATEGORY_IMAGE_WIDTH', '80', 'The width (in pixels) of category and manufacturer header images in product lists', 4, 5, now(), now(), NULL, NULL);
INSERT INTO configuration VALUES (NULL, 'Display Categories on Index', 'TOP_CATEGORIES_DISPLAY', 'false', 'Display categories on the shop index page', 10, 2, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Display Featured Products on Index', 'TOP_FEATURES_DISPLAY', 'false', 'Display featured products on the shop index page', 10, 3, now(), now(), NULL, 'shop_cfg_select_option(array(''true'', ''false''),');
INSERT INTO configuration VALUES (NULL, 'Product Display Mode', 'TOP_PRODUCTS_DISPLAY_MODE', 'Images', 'Display category products as list or product images', 10, 1, now(), now(), NULL, 'shop_cfg_select_option(array(''List'', ''Images''),');
INSERT INTO configuration VALUES (NULL, 'Standard HTTP URL', 'WEB_SERVER_ADDRESS', NULL, 'The full URL of your store (including http:// - leave blank for none)', 1, 2, now(), now(), NULL, NULL);


INSERT INTO countries VALUES (1,'Afghanistan','AF','AFG',1,2);
INSERT INTO countries VALUES (2,'Albania','AL','ALB',1,3);
INSERT INTO countries VALUES (3,'Algeria','DZ','DZA',1,1);
INSERT INTO countries VALUES (4,'American Samoa','AS','ASM',1,5);
INSERT INTO countries VALUES (5,'Andorra','AD','AND',1,3);
INSERT INTO countries VALUES (6,'Angola','AO','AGO',1,1);
INSERT INTO countries VALUES (7,'Anguilla','AI','AIA',1,0);
INSERT INTO countries VALUES (8,'Antarctica','AQ','ATA',1,0);
INSERT INTO countries VALUES (9,'Antigua and Barbuda','AG','ATG',1,4);
INSERT INTO countries VALUES (10,'Argentina','AR','ARG',1,6);
INSERT INTO countries VALUES (11,'Armenia','AM','ARM',1,2);
INSERT INTO countries VALUES (12,'Aruba','AW','ABW',1,0);
INSERT INTO countries VALUES (13,'Australia','AU','AUS',1,5);
INSERT INTO countries VALUES (14,'Austria','AT','AUT',5,3);
INSERT INTO countries VALUES (15,'Azerbaijan','AZ','AZE',1,2);
INSERT INTO countries VALUES (16,'Bahamas','BS','BHS',1,4);
INSERT INTO countries VALUES (17,'Bahrain','BH','BHR',1,2);
INSERT INTO countries VALUES (18,'Bangladesh','BD','BGD',1,2);
INSERT INTO countries VALUES (19,'Barbados','BB','BRB',1,4);
INSERT INTO countries VALUES (20,'Belarus','BY','BLR',1,3);
INSERT INTO countries VALUES (21,'Belgium','BE','BEL',1,3);
INSERT INTO countries VALUES (22,'Belize','BZ','BLZ',1,4);
INSERT INTO countries VALUES (23,'Benin','BJ','BEN',1,1);
INSERT INTO countries VALUES (24,'Bermuda','BM','BMU',1,0);
INSERT INTO countries VALUES (25,'Bhutan','BT','BTN',1,2);
INSERT INTO countries VALUES (26,'Bolivia','BO','BOL',1,6);
INSERT INTO countries VALUES (27,'Bosnia and Herzegowina','BA','BIH',1,3);
INSERT INTO countries VALUES (28,'Botswana','BW','BWA',1,1);
INSERT INTO countries VALUES (29,'Bouvet Island','BV','BVT',1,0);
INSERT INTO countries VALUES (30,'Brazil','BR','BRA',1,6);
INSERT INTO countries VALUES (31,'British Indian Ocean Territory','IO','IOT',1,2);
INSERT INTO countries VALUES (32,'Brunei Darussalam','BN','BRN',1,2);
INSERT INTO countries VALUES (33,'Bulgaria','BG','BGR',1,3);
INSERT INTO countries VALUES (34,'Burkina Faso','BF','BFA',1,1);
INSERT INTO countries VALUES (35,'Burundi','BI','BDI',1,1);
INSERT INTO countries VALUES (36,'Cambodia','KH','KHM',1,2);
INSERT INTO countries VALUES (37,'Cameroon','CM','CMR',1,1);
INSERT INTO countries VALUES (38,'Canada','CA','CAN',1,4);
INSERT INTO countries VALUES (39,'Cape Verde','CV','CPV',1,1);
INSERT INTO countries VALUES (40,'Cayman Islands','KY','CYM',1,0);
INSERT INTO countries VALUES (41,'Central African Republic','CF','CAF',1,1);
INSERT INTO countries VALUES (42,'Chad','TD','TCD',1,1);
INSERT INTO countries VALUES (43,'Chile','CL','CHL',1,6);
INSERT INTO countries VALUES (44,'China','CN','CHN',1,2);
INSERT INTO countries VALUES (45,'Christmas Island','CX','CXR',1,0);
INSERT INTO countries VALUES (46,'Cocos (Keeling) Islands','CC','CCK',1,0);
INSERT INTO countries VALUES (47,'Colombia','CO','COL',1,6);
INSERT INTO countries VALUES (48,'Comoros','KM','COM',1,1);
INSERT INTO countries VALUES (49,'Congo','CG','COG',1,1);
INSERT INTO countries VALUES (50,'Cook Islands','CK','COK',1,0);
INSERT INTO countries VALUES (51,'Costa Rica','CR','CRI',1,4);
INSERT INTO countries VALUES (52,'Cote D\'Ivoire','CI','CIV',1,1);
INSERT INTO countries VALUES (53,'Croatia','HR','HRV',1,3);
INSERT INTO countries VALUES (54,'Cuba','CU','CUB',1,4);
INSERT INTO countries VALUES (55,'Cyprus','CY','CYP',1,3);
INSERT INTO countries VALUES (56,'Czech Republic','CZ','CZE',1,3);
INSERT INTO countries VALUES (57,'Denmark','DK','DNK',1,3);
INSERT INTO countries VALUES (58,'Djibouti','DJ','DJI',1,1);
INSERT INTO countries VALUES (59,'Dominica','DM','DMA',1,4);
INSERT INTO countries VALUES (60,'Dominican Republic','DO','DOM',1,4);
INSERT INTO countries VALUES (61,'East Timor','TP','TMP',1,0);
INSERT INTO countries VALUES (62,'Ecuador','EC','ECU',1,6);
INSERT INTO countries VALUES (63,'Egypt','EG','EGY',1,1);
INSERT INTO countries VALUES (64,'El Salvador','SV','SLV',1,4);
INSERT INTO countries VALUES (65,'Equatorial Guinea','GQ','GNQ',1,1);
INSERT INTO countries VALUES (66,'Eritrea','ER','ERI',1,1);
INSERT INTO countries VALUES (67,'Estonia','EE','EST',1,3);
INSERT INTO countries VALUES (68,'Ethiopia','ET','ETH',1,1);
INSERT INTO countries VALUES (69,'Falkland Islands (Malvinas)','FK','FLK',1,0);
INSERT INTO countries VALUES (70,'Faroe Islands','FO','FRO',1,0);
INSERT INTO countries VALUES (71,'Fiji','FJ','FJI',1,5);
INSERT INTO countries VALUES (72,'Finland','FI','FIN',1,3);
INSERT INTO countries VALUES (73,'France','FR','FRA',1,3);
INSERT INTO countries VALUES (74,'France, Metropolitan','FX','FXX',1,0);
INSERT INTO countries VALUES (75,'French Guiana','GF','GUF',1,6);
INSERT INTO countries VALUES (76,'French Polynesia','PF','PYF',1,0);
INSERT INTO countries VALUES (77,'French Southern Territories','TF','ATF',1,0);
INSERT INTO countries VALUES (78,'Gabon','GA','GAB',1,1);
INSERT INTO countries VALUES (79,'Gambia','GM','GMB',1,1);
INSERT INTO countries VALUES (80,'Georgia','GE','GEO',1,2);
INSERT INTO countries VALUES (81,'Germany','DE','DEU',5,3);
INSERT INTO countries VALUES (82,'Ghana','GH','GHA',1,1);
INSERT INTO countries VALUES (83,'Gibraltar','GI','GIB',1,0);
INSERT INTO countries VALUES (84,'Greece','GR','GRC',1,3);
INSERT INTO countries VALUES (85,'Greenland','GL','GRL',1,4);
INSERT INTO countries VALUES (86,'Grenada','GD','GRD',1,4);
INSERT INTO countries VALUES (87,'Guadeloupe','GP','GLP',1,0);
INSERT INTO countries VALUES (88,'Guam','GU','GUM',1,0);
INSERT INTO countries VALUES (89,'Guatemala','GT','GTM',1,4);
INSERT INTO countries VALUES (90,'Guinea','GN','GIN',1,0);
INSERT INTO countries VALUES (91,'Guinea-bissau','GW','GNB',1,1);
INSERT INTO countries VALUES (92,'Guyana','GY','GUY',1,6);
INSERT INTO countries VALUES (93,'Haiti','HT','HTI',1,4);
INSERT INTO countries VALUES (94,'Heard and Mc Donald Islands','HM','HMD',1,0);
INSERT INTO countries VALUES (95,'Honduras','HN','HND',1,4);
INSERT INTO countries VALUES (96,'Hong Kong','HK','HKG',1,2);
INSERT INTO countries VALUES (97,'Hungary','HU','HUN',1,3);
INSERT INTO countries VALUES (98,'Iceland','IS','ISL',1,3);
INSERT INTO countries VALUES (99,'India','IN','IND',1,0);
INSERT INTO countries VALUES (100,'Indonesia','ID','IDN',1,2);
INSERT INTO countries VALUES (101,'Iran (Islamic Republic of)','IR','IRN',1,2);
INSERT INTO countries VALUES (102,'Iraq','IQ','IRQ',1,2);
INSERT INTO countries VALUES (103,'Ireland','IE','IRL',1,3);
INSERT INTO countries VALUES (104,'Israel','IL','ISR',1,2);
INSERT INTO countries VALUES (105,'Italy','IT','ITA',1,3);
INSERT INTO countries VALUES (106,'Jamaica','JM','JAM',1,4);
INSERT INTO countries VALUES (107,'Japan','JP','JPN',1,2);
INSERT INTO countries VALUES (108,'Jordan','JO','JOR',1,2);
INSERT INTO countries VALUES (109,'Kazakhstan','KZ','KAZ',1,0);
INSERT INTO countries VALUES (110,'Kenya','KE','KEN',1,1);
INSERT INTO countries VALUES (111,'Kiribati','KI','KIR',1,5);
INSERT INTO countries VALUES (112,'Korea, Democratic People\'s Republic of','KP','PRK',1,2);
INSERT INTO countries VALUES (113,'Korea, Republic of','KR','KOR',1,2);
INSERT INTO countries VALUES (114,'Kuwait','KW','KWT',1,2);
INSERT INTO countries VALUES (115,'Kyrgyzstan','KG','KGZ',1,2);
INSERT INTO countries VALUES (116,'Lao People\'s Democratic Republic','LA','LAO',1,0);
INSERT INTO countries VALUES (117,'Latvia','LV','LVA',1,3);
INSERT INTO countries VALUES (118,'Lebanon','LB','LBN',1,2);
INSERT INTO countries VALUES (119,'Lesotho','LS','LSO',1,1);
INSERT INTO countries VALUES (120,'Liberia','LR','LBR',1,1);
INSERT INTO countries VALUES (121,'Libyan Arab Jamahiriya','LY','LBY',1,1);
INSERT INTO countries VALUES (122,'Liechtenstein','LI','LIE',1,3);
INSERT INTO countries VALUES (123,'Lithuania','LT','LTU',1,3);
INSERT INTO countries VALUES (124,'Luxembourg','LU','LUX',1,3);
INSERT INTO countries VALUES (125,'Macau','MO','MAC',1,0);
INSERT INTO countries VALUES (126,'Macedonia, The Former Yugoslav Republic of','MK','MKD',1,3);
INSERT INTO countries VALUES (127,'Madagascar','MG','MDG',1,1);
INSERT INTO countries VALUES (128,'Malawi','MW','MWI',1,1);
INSERT INTO countries VALUES (129,'Malaysia','MY','MYS',1,2);
INSERT INTO countries VALUES (130,'Maldives','MV','MDV',1,2);
INSERT INTO countries VALUES (131,'Mali','ML','MLI',1,1);
INSERT INTO countries VALUES (132,'Malta','MT','MLT',1,3);
INSERT INTO countries VALUES (133,'Marshall Islands','MH','MHL',1,5);
INSERT INTO countries VALUES (134,'Martinique','MQ','MTQ',1,0);
INSERT INTO countries VALUES (135,'Mauritania','MR','MRT',1,1);
INSERT INTO countries VALUES (136,'Mauritius','MU','MUS',1,1);
INSERT INTO countries VALUES (137,'Mayotte','YT','MYT',1,0);
INSERT INTO countries VALUES (138,'Mexico','MX','MEX',1,4);
INSERT INTO countries VALUES (139,'Micronesia, Federated States of','FM','FSM',1,5);
INSERT INTO countries VALUES (140,'Moldova, Republic of','MD','MDA',1,3);
INSERT INTO countries VALUES (141,'Monaco','MC','MCO',1,3);
INSERT INTO countries VALUES (142,'Mongolia','MN','MNG',1,2);
INSERT INTO countries VALUES (143,'Montserrat','MS','MSR',1,0);
INSERT INTO countries VALUES (144,'Morocco','MA','MAR',1,1);
INSERT INTO countries VALUES (145,'Mozambique','MZ','MOZ',1,1);
INSERT INTO countries VALUES (146,'Myanmar','MM','MMR',1,2);
INSERT INTO countries VALUES (147,'Namibia','NA','NAM',1,1);
INSERT INTO countries VALUES (148,'Nauru','NR','NRU',1,5);
INSERT INTO countries VALUES (149,'Nepal','NP','NPL',1,2);
INSERT INTO countries VALUES (150,'Netherlands','NL','NLD',1,3);
INSERT INTO countries VALUES (151,'Netherlands Antilles','AN','ANT',1,0);
INSERT INTO countries VALUES (152,'New Caledonia','NC','NCL',1,0);
INSERT INTO countries VALUES (153,'New Zealand','NZ','NZL',1,5);
INSERT INTO countries VALUES (154,'Nicaragua','NI','NIC',1,4);
INSERT INTO countries VALUES (155,'Niger','NE','NER',1,1);
INSERT INTO countries VALUES (156,'Nigeria','NG','NGA',1,1);
INSERT INTO countries VALUES (157,'Niue','NU','NIU',1,0);
INSERT INTO countries VALUES (158,'Norfolk Island','NF','NFK',1,0);
INSERT INTO countries VALUES (159,'Northern Mariana Islands','MP','MNP',1,0);
INSERT INTO countries VALUES (160,'Norway','NO','NOR',1,3);
INSERT INTO countries VALUES (161,'Oman','OM','OMN',1,2);
INSERT INTO countries VALUES (162,'Pakistan','PK','PAK',1,2);
INSERT INTO countries VALUES (163,'Palau','PW','PLW',1,5);
INSERT INTO countries VALUES (164,'Panama','PA','PAN',1,4);
INSERT INTO countries VALUES (165,'Papua New Guinea','PG','PNG',1,5);
INSERT INTO countries VALUES (166,'Paraguay','PY','PRY',1,6);
INSERT INTO countries VALUES (167,'Peru','PE','PER',1,6);
INSERT INTO countries VALUES (168,'Philippines','PH','PHL',1,2);
INSERT INTO countries VALUES (169,'Pitcairn','PN','PCN',1,0);
INSERT INTO countries VALUES (170,'Poland','PL','POL',1,3);
INSERT INTO countries VALUES (171,'Portugal','PT','PRT',1,3);
INSERT INTO countries VALUES (172,'Puerto Rico','PR','PRI',1,0);
INSERT INTO countries VALUES (173,'Qatar','QA','QAT',1,2);
INSERT INTO countries VALUES (174,'Reunion','RE','REU',1,0);
INSERT INTO countries VALUES (175,'Romania','RO','ROM',1,3);
INSERT INTO countries VALUES (176,'Russian Federation','RU','RUS',1,2);
INSERT INTO countries VALUES (177,'Rwanda','RW','RWA',1,1);
INSERT INTO countries VALUES (178,'Saint Kitts and Nevis','KN','KNA',1,4);
INSERT INTO countries VALUES (179,'Saint Lucia','LC','LCA',1,4);
INSERT INTO countries VALUES (180,'Saint Vincent and the Grenadines','VC','VCT',1,4);
INSERT INTO countries VALUES (181,'Samoa','WS','WSM',1,0);
INSERT INTO countries VALUES (182,'San Marino','SM','SMR',1,3);
INSERT INTO countries VALUES (183,'Sao Tome and Principe','ST','STP',1,1);
INSERT INTO countries VALUES (184,'Saudi Arabia','SA','SAU',1,2);
INSERT INTO countries VALUES (185,'Senegal','SN','SEN',1,1);
INSERT INTO countries VALUES (186,'Seychelles','SC','SYC',1,1);
INSERT INTO countries VALUES (187,'Sierra Leone','SL','SLE',1,1);
INSERT INTO countries VALUES (188,'Singapore','SG','SGP',4,2);
INSERT INTO countries VALUES (189,'Slovakia (Slovak Republic)','SK','SVK',1,3);
INSERT INTO countries VALUES (190,'Slovenia','SI','SVN',1,3);
INSERT INTO countries VALUES (191,'Solomon Islands','SB','SLB',1,5);
INSERT INTO countries VALUES (192,'Somalia','SO','SOM',1,1);
INSERT INTO countries VALUES (193,'South Africa','ZA','ZAF',1,1);
INSERT INTO countries VALUES (194,'South Georgia and the South Sandwich Islands','GS','SGS',1,0);
INSERT INTO countries VALUES (195,'Spain','ES','ESP',3,3);
INSERT INTO countries VALUES (196,'Sri Lanka','LK','LKA',1,2);
INSERT INTO countries VALUES (197,'St. Helena','SH','SHN',1,0);
INSERT INTO countries VALUES (198,'St. Pierre and Miquelon','PM','SPM',1,0);
INSERT INTO countries VALUES (199,'Sudan','SD','SDN',1,1);
INSERT INTO countries VALUES (200,'Suriname','SR','SUR',1,6);
INSERT INTO countries VALUES (201,'Svalbard and Jan Mayen Islands','SJ','SJM',1,0);
INSERT INTO countries VALUES (202,'Swaziland','SZ','SWZ',1,1);
INSERT INTO countries VALUES (203,'Sweden','SE','SWE',1,3);
INSERT INTO countries VALUES (204,'Switzerland','CH','CHE',1,3);
INSERT INTO countries VALUES (205,'Syrian Arab Republic','SY','SYR',1,2);
INSERT INTO countries VALUES (206,'Taiwan','TW','TWN',1,2);
INSERT INTO countries VALUES (207,'Tajikistan','TJ','TJK',1,2);
INSERT INTO countries VALUES (208,'Tanzania, United Republic of','TZ','TZA',1,1);
INSERT INTO countries VALUES (209,'Thailand','TH','THA',1,2);
INSERT INTO countries VALUES (210,'Togo','TG','TGO',1,1);
INSERT INTO countries VALUES (211,'Tokelau','TK','TKL',1,0);
INSERT INTO countries VALUES (212,'Tonga','TO','TON',1,5);
INSERT INTO countries VALUES (213,'Trinidad and Tobago','TT','TTO',1,4);
INSERT INTO countries VALUES (214,'Tunisia','TN','TUN',1,1);
INSERT INTO countries VALUES (215,'Turkey','TR','TUR',1,2);
INSERT INTO countries VALUES (216,'Turkmenistan','TM','TKM',1,2);
INSERT INTO countries VALUES (217,'Turks and Caicos Islands','TC','TCA',1,0);
INSERT INTO countries VALUES (218,'Tuvalu','TV','TUV',1,5);
INSERT INTO countries VALUES (219,'Uganda','UG','UGA',1,1);
INSERT INTO countries VALUES (220,'Ukraine','UA','UKR',1,3);
INSERT INTO countries VALUES (221,'United Arab Emirates','AE','ARE',1,2);
INSERT INTO countries VALUES (222,'United Kingdom (Great Britain)','GB','GBR',1,3);
INSERT INTO countries VALUES (223,'United States','US','USA',2,4);
INSERT INTO countries VALUES (224,'United States Minor Outlying Islands','UM','UMI',1,0);
INSERT INTO countries VALUES (225,'Uruguay','UY','URY',1,6);
INSERT INTO countries VALUES (226,'Uzbekistan','UZ','UZB',1,2);
INSERT INTO countries VALUES (227,'Vanuatu','VU','VUT',1,5);
INSERT INTO countries VALUES (228,'Vatican City State (Holy See)','VA','VAT',1,3);
INSERT INTO countries VALUES (229,'Venezuela','VE','VEN',1,6);
INSERT INTO countries VALUES (230,'Viet Nam','VN','VNM',1,0);
INSERT INTO countries VALUES (231,'Virgin Islands (British)','VG','VGB',1,0);
INSERT INTO countries VALUES (232,'Virgin Islands (U.S.)','VI','VIR',1,0);
INSERT INTO countries VALUES (233,'Wallis and Futuna Islands','WF','WLF',1,0);
INSERT INTO countries VALUES (234,'Western Sahara','EH','ESH',1,0);
INSERT INTO countries VALUES (235,'Yemen','YE','YEM',1,2);
INSERT INTO countries VALUES (236,'Yugoslavia','YU','YUG',1,0);
INSERT INTO countries VALUES (237,'Zaire','ZR','ZAR',1,0);
INSERT INTO countries VALUES (238,'Zambia','ZM','ZMB',1,1);
INSERT INTO countries VALUES (239,'Zimbabwe','ZW','ZWE',1,1);

INSERT INTO currencies VALUES (1,'US Dollar','USD','$',NULL,'.',',',2,1.00000000,now());
INSERT INTO currencies VALUES (2,'European Euro','EUR','&euro;',NULL,'.',',',2,0.81999999,now());
INSERT INTO currencies VALUES (3,'English Pound','GBP','&pound;',NULL,'.',',',2,0.56000000,now());
INSERT INTO currencies VALUES (4,'Canadian Dollar','CAD','$',NULL,'.',',',2,1.29999995,now());
INSERT INTO currencies VALUES (5,'Japanese Yen','JPY','&yen;',NULL,'.',',',0,107.00000000,now());
INSERT INTO currencies VALUES (6,'Australian Dollar','AUD','$',NULL,'.',',',2,1.30999994,now());
INSERT INTO currencies VALUES (7,'New Zealand Dollar','NZD','$',NULL,'.',',',2,1.50000000,now());

INSERT INTO geo_zones VALUES (1,'Default Zone','Contains the zones local to my store.',now(),now());

INSERT INTO information_documents VALUES (1,1,1,'Canceling Your Order','After you have clicked \"Confirm Order,\" your order begins to process and you cannot make any online changes to your order.\r\r<p>To cancel your order prior to shipment, you must <a href=\"contact_us.php\">contact customer service</a>. Please note that most orders process quickly and can enter the shipping process within minutes. If your order has already entered the shipping process, it cannot be changed or canceled.\r\r<p>Items that were specially configured by you are custom manufactured and cannot be canceled once production has commenced.',1);
INSERT INTO information_documents VALUES (2,1,1,'Changing Your Order','After you have clicked \"Confirm Order,\" your order begins to process and you cannot make any online changes to your order.\r\r<p>To change or cancel your order prior to shipment, you must <a href=\"contact_us.php\">contact customer service</a>. Please note that most orders process quickly and can enter the shipping process within minutes. If your order has already entered the shipping process, it cannot be changed or canceled.',1);
INSERT INTO information_documents VALUES (3,1,1,'Our Products','<B>Q</B>: Who should I contact with questions concerning a manufacturer\'s warranty? \r<br /><B>A</B>: Contact the manufacturer directly with questions concerning a manufacturer\'s warranty. We can provide you with additional warranty information or information on how to obtain a copy of the manufacturer\'s warranty for a specific product, if you <a href=\"contact_us.php\">contact customer service</a>. Please specify the product name, manufacturer name and online item number in your e-mail. \r\r<p><B>Q</B>: Does [store_name] offer extended warranties for any products? \r<br /><B>A</B>: We do not currently offer or extend product warranties for any products. \r\r<p><B>Q</B>: Is it possible to alter, add, or change a items I see on [store_name]? \r<br /><B>A</B>: Some items on our site can be special ordered and configured to your specifications right online. Such items are non-cancelable because they are being produced to your specifications.  Production time for these items will be longer than regular items.\r\r<p><B>Q</B>: How do I know your products are authentic? \r<br /><B>A</B>: We guarantee all of our merchandise is genuine and authentic.',1);
INSERT INTO information_documents VALUES (4,1,1,'Our Shopping Cart','When you are shopping on [store_name] and add an item to your cart, it is saved in your Shopping Cart. The Shopping Cart holds products you wish to purchase while you shop, the same way you use a shopping cart in a retail store. Options in the Shopping Cart:\r\r<p><b>Update the quantity</b>\r\r<p>To do this, simply type in the quantity you wish to purchase and click \"Update Cart.\" \r\r<p><b>Remove an item from your Shopping Cart.</b>\r\r<p>To remove an item, click on the \"Remove\" check box and click \"Update Cart.\" \r\r<p><b>Return to shopping</b>\r\r<p>If you wish to continue shopping on [store_name], you can use the Shopping Cart to store items you wish to purchase. Click on \"Continue Shopping\" to search the site for additional items. At any time during your shopping experience, you can return to your Shopping Cart by clicking on \"Shopping Cart.\" \r\r<p><b>Proceed to secure Checkout</b>\r\r<p>When you are ready to purchase your item(s), click on  \"Checkout.\" Our checkout process is fast, easy and secure.',1);
INSERT INTO information_documents VALUES (5,1,1,'Our Web Site','<B>Q</B>: What is the fastest way to find a particular product on [store_name]? \r<br /><B>A</B>: Use our convenient, cross-category, keyword search Quick Find feature. You can search by item number, model name or key word(s) describing the product. Also, you will find links to product categories located on the left side of your screen throughout your shopping experience. \r\r<p><B>Q</B>: How often is the stock updated on [store_name]? \r<br /><B>A</B>: We are constantly adding to our expansive collection of products. By regularly updating our product lines we are able to supply you with seasonal favorites as well as the most current trends. \r\r<p><B>Q</B>: If I subscribe to the [store_name] newsletter, will my e-mail address remain confidential? How often will I receive the newsletter? \r<br /><B>A</B>: Information such as account or credit card numbers and demographic information such as zip code, age, and income level are used only to send orders, our company newsletter and other e-mail promotions pertinent to the [store_name] site. This information is not shared with any outside parties. We generally send out newsletters every other week, but may vary depending on the time of year. \r\r<p><B>Q</B>: What shipping methods are available? \r<br /><B>A</B>: We currently offer a variety of expedited and standard delivery options. \r\r<p><B>Q</B>: Is international shipping available? To what international destinations do you ship? \r<br /><B>A</B>: We currently ship to international addresses in a limited number of countries, all of which are listed in our International Shipping information .\r\r<p><B>Q</B>: What forms of payment are accepted? \r<br /><B>A</B>: We currently accept most major credit cards, personal check, money order, cashier\'s check, certified bank check, wire transfer, as well as gift certificates.\r\r<p><B>Q</B>: Can I use more than one credit card to pay for my web order? \r<br /><B>A</B>: No, currently we only accept one credit card number per web order.\r\r<p><B>Q</B>: How do I know when my order has been received? \r<br /><B>A</B>: Once your order has been received, you will receive an e-mail from us. This e-mail confirms that we have received your order and it includes your order number. Keep this e-mail for your records. \r\r<p><B>Q</B>: How do I know when my order has been shipped? \r<br /><B>A</B>: Once your order has been shipped, you will receive an e-mail from us. This e-mail confirms that your order or part of your order has shipped. You may receive multiple e-mails depending on the items you selected. \r\r<p><B>Q</B>: Can I cancel my order? \r<br /><B>A</B>: After you have clicked \"Confirm Order,\" your order begins to process and you cannot make any online changes to your order. To change or cancel your order prior to shipment, you must <a href=\"contact_us.php\">contact customer service</a>. Please note that most orders process quickly and can enter the shipping process within minutes. If your order has already entered the shipping process, it cannot be changed or canceled. \r\r<p><B>Q</B>: How can I track my order? \r<br /><B>A</B>: We do not release tracking numbers but we provide online tracking for your convenience. Just click on the \"Track Your Order\" link and you can track the status of your delivery with your order number. This feature is only available for UPS shipments. \r\r<p><B>Q</B>: Can [store_name] provide me with my order\'s tracking number so that I can track it myself? \r<br /><B>A</B>: It is our company policy that we do not release tracking numbers. We do provide online tracking for your convenience. Just login to your account and you can track the delivery status of any order.  \r<br />  \r<br /><B>Q</B>: Can I ship to my office or another residential address even if it is different than my billing address? \r<br /><B>A</B>: While, you can ship to an office address, a residential address other than your billing address must be listed with your credit card company \r\r<p><B>Q</B>: Are the product images on your site photographs of the actual merchandise? \r<br /><B>A</B>: Yes, all of the product images on [store_name] are images of our actual merchandise. \r\r<p><B>Q</B>: During the order and shipment process, when is my credit card billed? \r<br /><B>A</B>: Your credit card is billed when your order is received. \r\r<p><B>Q</B>: Do I have to pay sales tax on my online purchase? \r<br /><B>A</B>: Since [store_name] is based in [store_zone], state law requires that we charge sales tax on orders shipped to customers residing in [store_zone]. To customers residing in states other than [store_zone], please be aware that, if applicable, the taxing authorities in your state may charge you a \"use\" tax on your out-of-state internet and/or catalog purchases. While it is not the responsibility of [store_name] to charge or collect this \"use\" tax from you at this time, we are alerting our customers regarding this possibility as a courtesy. If you require further information on this issue, we suggest you contact the tax authorities in your state directly. \r\r<p><B>Q</B>: Can I get a catalog of your product assortment sent to me? \r<br /><B>A</B>: You can only view the [store_name] product assortment online in our web store.',1);
INSERT INTO information_documents VALUES (6,1,1,'Returns','<B>Q</B>: What are the steps I need to take to return an item to [store_name]? \r<br /><B>A</B>: You must obtain a Return For Inspection (RFI) number prior to returning any product to [store_name]. For complete instructions on returning a product to [store_name], please read the Returns and Repairs section. \r\r<p><B>Q</B>: Why must I obtain a Return For Inspection (RFI) number prior to returning an item to [store_name]? \r<br /><B>A</B>: You must obtain an RFI number so that we can easily identify your package when it is returned to our warehouse. Prompt identification allows for expedited handling. Any package returned to our warehouse that does not have an RFI number will not be accepted. \r\r<p><B>Q</B>: When can I expect to receive the item I sent to [store_name] for repair? \r<br /><B>A</B>: We will notify you of the status of your repair by e-mail or by phone. The length of time it takes for us to repair your item depends on the nature of the repair. \r\r<p><B>Q</B>: Can I exchange a product I purchased on [store_name]? \r<br /><B>A</B>: You can exchange an item as long as the original purchase meets all of the return criteria. However, we will not reship a product until we receive the original item back for inspection. \r\r<p><B>Q</B>: Can I return an item for store credit? \r<br /><B>A</B>: An item may be returned for store credit provided that all return guidelines are met. \r\r<p><B>Q</B>: Are [store_name] gift certificates refundable? \r<br /><B>A</B>: No. [store_name] gift certificates are non-refundable. \r\r<p><B>Q</B>: Does [store_name] make repairs that are not covered by a manufacturer\'s warranty? \r<br /><B>A</B>: Depending upon the type of merchandise, the [store_name]s repair center may make repairs that are not covered by a product\'s warranty. Customers will be charged for those types of repairs. An evaluation is made once the item is returned to us, at which time the Service Department will contact you with details about the repairs and cost involved \r\r<p><B>Q</B>: How do I know what is covered under my manufacturer\'s warranty? \r<br /><B>A</B>: All warranties are limited unless stated otherwise. For further information regarding warranties, please refer to our Warranty section of our Help Desk. \r\r<p><B>Q</B>: Is there a restocking fee on any returned merchandise? \r<br /><B>A</B>: Generally no, UNLESS the returned merchandise was a layaway sale or was considered a return exception, in which cases you will be charged a 25% restocking fee. \r\r<p><B>Q</B>: May I return merchandise that was special ordered or customized? \r<br /><B>A</B>: Merchandise that was special ordered or customized cannot be returned. \r\r<p><B>Q</B>: Is there a preferred method by which I should return an item to [store_name]? \r<br /><B>A</B>: Ship your return prepaid and insured for the full purchase price by a carrier that offers package tracking, such as United Parcel Service (UPS) or Federal Express to the address listed at the top of the invoice.',1);
INSERT INTO information_documents VALUES (7,2,1,'Cancellations','Occasionally, orders or parts of an order are cancelled by our system for various reasons. Some reasons are: \r\r<p>&bull; Item(s) not available. \r<br />&bull; Difficulty in processing your payment information. \r<br />&bull; Cannot ship to address provided. \r<br />&bull; Duplicate order was placed. \r<br />&bull; Cancelled due to a customer request. \r\r<p>If your order is cancelled, you will receive an important notice regarding your order via e-mail which will explain the reason for the cancellation. You will not be billed for any cancelled items. If you are interested in alternative products, please <a href=\"contact_us.php\">contact customer service</a> by e-mail for a recommendation.',1);
INSERT INTO information_documents VALUES (8,2,1,'Limited Warranty','[store_name] provides warranty coverage of generally two years from the date of purchase on all of its brand name watches. Our warranty covers the watch movement and battery replacement for the time period stated and excludes:\r\r<p>&bull; watch case, watch bracelet, straps, crown/stem, crystal/glass, finishes, damage caused by excessive wear and tear and/or physical/accidental abuse, and \r\r<p>&bull; damage resulting from wear under conditions exceeding the watch manufacturer\'s water resistance limitations. \r\r<p>All shipping and handling costs in connection with warranty service are the responsibility of the customer. This warranty is valid only at [store_name]. Improper repair or warranty service performed by someone other than [store_name] will void this warranty.\r\r<p>[store_name] DISCLAIMS ANY LIABILITY FOR CONSEQUENTIAL OR INCIDENTAL DAMAGES FOR BREACH OF WRITTEN OR IMPLIED WARRANTY OF THIS WATCH, INCLUDING MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. THIS WARRANTY GIVES YOU SPECIFIC LEGAL RIGHTS, AND YOU MAY ALSO HAVE OTHER RIGHTS, WHICH VARY FROM STATE TO STATE. Some states do not allow the exclusion or limitation of incidental or consequential damages, so the above limitation may not apply to you. For additional questions concerning warranty service, please contact our customer service Department.',1);
INSERT INTO information_documents VALUES (9,2,1,'Privacy Policy','This privacy statement discloses the privacy practices for our website: [store_name] \r\r<p>[store_name] has created this privacy policy to inform you of the information gathering and dissemination practices for this Web site, [store_name]. Because [store_name] wants to demonstrate its commitment to your privacy, we have agreed to disclose our information practices and notify you of: \r\r<p>&bull; What personally identifiable information (or third party personally identifiable information) of yours is collected from you through our website \r<br />&bull; The organization collecting the information \r<br />&bull; How the information is used \r<br />&bull; With whom the information may be shared \r<br />&bull; What choices are available to you regarding collection, use and distribution of the information \r<br />&bull; The kind of security procedures that are in place to protect the loss, misuse or alteration of information under [store_name]\'s control \r<br />&bull; How you can correct any inaccuracies in the information. \r\r<p>If you feel that [store_name] is not abiding by its posted privacy policy, you should <a href=\"contact_us.php\">contact us</a>. \r\r<p><b>Information Collection and Use </b>\r\r<p>[store_name] is the sole owner of the information collected on this site. We will not sell, share, or rent this information to others in ways different from what is disclosed in this statement. [store_name] collects information from our users at several different points on our website. \r\r<p><b>Membership </b>\r\r<p>When you make a purchase on our site, you automatically become a member. You provide the following information to [store_name]: \r\r<p>&bull; Your name \r<br />&bull; Your e-mail address \r<br />&bull; Your billing and shipping address \r<br />&bull; Your telephone number \r<br />&bull; The type of credit card you are using if applicable \r<br />&bull; Your credit card number and expiration date, or other form of payment \r\r<p>Your Email address is your member identification. You choose your own password to access your account. All members can choose whether or not they would like to receive electronic mailings from [store_name] (see \"Electronic Mailings\" below). \r\r<p><b>Order </b>\r\r<p>We request information from the user on our order form when making a purchase. Here, is where a user must provide their contact information, like name and shipping address, and shipping information,  credit card number and expiration date. This information is used for billing purposes and to fill the customer\'s order. If we have difficulty processing an order, this contact information is used to get in touch with the customer. \r\r<p><b>Cookies </b>\r\r<p>A cookie is a piece of data stored on the user\'s hard drive containing information about the user. We use both session and persistent cookies. Usage of a cookie from our site is in no way linked to any personally identifiable information. Cookies enable us to track and target the interests of our users in the aggregate by analyzing popular areas and products to enhance future experiences on our site.\r\r<p><b>Usage Tracking </b>\r\r<p>[store_name]\'s database tracks the traffic throughout our site. This information is used to compile overall statistics and is not recorded at an individual level. This includes IP (internet protocol) addresses, browser type, ISP (internet service provider), referring/exit pages, platform type, date/time stamp, and #of clicks to analyze trends, administer the site, track user\'s movement in the aggregate. The statistics help us determine which products and services best serve our members and guests. \r\r<p><b>Aggregate Information</b>\r\r<p>[store_name] uses aggregate information from demographic surveys, traffic patterns and IP addresses to customize our site. Aggregate information is occasionally shared with partners of [store_name] to plan advertising or promotions. We do not share any personally identifiable information. \r\r<p><b>Sharing</b>\r\r<p>[store_name] gives you access to third party partners to provide you with certain services that are detailed below. [store_name] will provide that third party with your transaction information and then that third party will collect additional information if needed to provide you with the requested service. These third parties are not allowed to use personally identifiable information except for the purpose of providing these services. \r\r<p>We use outside shipping companies to ship orders, and a credit card processing company to bill users for goods and services. These companies do not retain, share, store or use personally identifiable information for any secondary purposes. \r\r<p><b>Links </b>\r\r<p>This website contains links to other sites. Please be aware that we are not responsible for the privacy practices of such other sites. We encourage our users to be aware when they leave our site and to read the privacy statements of each and every website that collects personally identifiable information. This privacy policy applies solely to information collected by [store_name]. \r\r<p><b>Catalog, Newsletters, Etc. </b>\r\r<p>If a user wishes to subscribe to our catalog, newsletter, etc., we ask for contact information such as name, street address and Email address to provide these communications. Out of respect for our users privacy we provide a way to opt-out of these communications. Please see the choice and opt-out section below. \r\r<p>On rare occasions it is necessary to send out a strictly service related announcement. For instance, if our service is temporarily suspended for maintenance we might send you an Email. Generally, users may not opt-out of these communications, though you can deactivate your account. However, these communications are not promotional in nature. \r\r<p><b>Surveys &amp; Sweepstakes</b>\r\r<p>From time to time, our site requests information from users via surveys or sweepstakes. Participation in these surveys or sweepstakes is completely voluntary and the user therefore has a choice whether or not to disclose this information. Information requested may include contact information (such as name, shipping address and Email address), and demographic information (such as zip code, age level). Contact information will be used to notify the winners and award prizes. Survey information will be used for purposes of monitoring or improving the use and satisfaction of this site. \r\r<p><b>Tell-A-Friend</b>\r\r<p>If a user elects to use our referral service for informing a friend about an item, we ask them for the friend\'s name and Email address. [store_name] will automatically send the friend a one-time Email inviting them to visit the site. We do store the friend\'s Email and they have an option to opt-out in the communication. \r\r<p><b>Security</b>\r\r<p>[store_name] takes every precaution to protect our users\' information. When users submit sensitive information via our website, your information is protected both online and off-line. \r\r<p>When our registration/order form asks users to enter sensitive information (such as credit card number and/or social security number), that information is encrypted and is protected with the best encryption software in the industry - Secure Socket Layers (SSLs). While on a secure page, such as our order form, a lock icon appears on the bottom of your Web browser. When you are not on a secure page, no lock icon will appear. \r\r<p>While we use SSL encryption to protect sensitive information (like your credit card information) online, we also do everything in our power to protect user information off-line. All of our users\' information, not just the sensitive information mentioned above, is restricted in our offices. Only employees who need the information to perform a specific job (for example, our billing clerk or a customer service representative) are granted access to personally identifiable information. Our employees must use password-protected screen-savers when they leave their desk. When they return, they must re-enter their password to regain access to your information. Furthermore, ALL employees are fully informed about our security and privacy practices and updated as new policies are added or revised. They are regularly notified and/or reminded about the importance we place on privacy, and what they can do to ensure that our customers\' information is protected. Finally, the servers that we store personally identifiable information on are kept in a secure environment under restricted access. \r\r<p>If you have any questions about the security at our website you may <a href=\"contact_us.php\">contact us</a>. \r\r<p><b>Special Offers</b>\r\r<p>Established members will occasionally receive information on products, services, special offers and a newsletter. Out of respect for the privacy of our users, we present the option to not receive these types of communications. Please see our choice and opt-out below. \r\r<p><b>Correcting/Updating/Deleting/Deactivating </b>\r\r<p>If a user\'s personally identifiable information changes (such as your zip code, phone, Email or postal address), or if a user no longer desires our service, we provide a way to correct, update or delete/deactivate that user\'s personally identifiable information provided to us. This can be done by using the unsubscribe feature in our communication. \r\r<p><b>Choice/Opt-Out</b>\r\r<p>Our users are given the opportunity to \'opt-out\' of having their information used for purposes not directly related to our site at the point where we ask for the information. For example, our order form has an \'opt-out\' mechanism so users who buy a product from us, but don\'t want any marketing material, can keep their Email address off of our lists. \r\r<p>If we decided to change our privacy policy, we will post those changes to this privacy statement, the homepage, and other places we deem appropriate so our users are always aware of what information we collect, how we use it, and under what circumstances, if any, we disclose it. We will use information in accordance with the privacy policy under which the information was collected. \r\r<p>If, however, we are going to use your personally identifiable information in a manner different from that stated at the time of collection we will notify you via Email. You will have a choice as to whether or not we use your information in this different manner. However, if you have opted out of all communication with the site, or deleted/deactivated your account, then you will not be contacted, nor will your personal information be used in this new manner. In addition, if we make any material changes in our privacy practices that do not affect user information already stored in our database, we will post a prominent notice on our web site notifying users of the change. In some cases where we post a notice we will also Email users, who have opted to receive communications from us, notifying them of the changes in our privacy practices.',1);
INSERT INTO information_documents VALUES (10,3,1,'Credits','You can expect a refund in the same form of payment originally used for purchase as soon as possible upon our receipt of your returned product. You will be refunded the shipping cost up to a maximum of $12.00 if the return is a result of a shipping error on our part.',1);
INSERT INTO information_documents VALUES (11,3,1,'Damaged/Defective Items','If you receive a damaged or incorrect item, <a href=\"contact_us.php\">contact customer service</a> no later than 5 business days of receipt.  On a case by case basis, we will cover shipping charges up to a maximum of $12.00 upon our receipt of the defective or mis-delivered item which must be returned fully intact with the original packaging via common carrier that provides package tracking.\r\r<p>If there is extensive damage to the carton, refuse the order and <a href=\"contact_us.php\">contact customer service</a> immediately. Please have your order number available when you <a href=\"contact_us.php\">contact customer service</a>.',1);
INSERT INTO information_documents VALUES (12,3,1,'Money Back Guarantee','We want you to be fully satisfied with every item that you purchase online from [store_name]. If you are not satisfied with an item that you have purchased online, you may return the item for a full refund of the purchase price, minus the shipping, handling, or other charges, subject to the time period specific to that product and according to our Return/Exchange Instructions .\r\r<p>The item must be returned in new and unused condition, in the original boxes and with all paperwork (this includes warranties), parts and accessories to insure full credit. \"New and unused\" means that there are no scratches, marks, or blemishes on the item; there are no signs of wear on the product, the tags, or the case; if applicable, the clear plastic wrapping has not been torn or removed; and the product must not have been sized or altered in any way. We cannot accept a return of any item with any indication that it has been used. \r\r<p>All items properly returned under this policy are eligible for a refund or a store credit, at your option. If you choose a refund, the adjusted purchase price will be credited in the same form of payment used for the original purchase.',1);
INSERT INTO information_documents VALUES (13,3,1,'Repairs','While the incidence of defects in new items is extremely low, there may be occasions in which repair work becomes necessary (while the product is still under warranty). In most cases, any warranty repair work will be handled directly by [store_name] on our premises. However, in some cases in which the manufacturer is the authorized service center, all repairs or replacements will be handled by the manufacturer.  Please refer to the warranty card accompanying the product for details.',1);
INSERT INTO information_documents VALUES (14,3,1,'Returns &amp; Exchanges','You may return \"new and unused\" merchandise that has not been special ordered within 30 days of ship date as stated in our Returns section for a full refund of the purchase price, minus the shipping, handling, gift packaging, or other charges within 15 days of ship date.\r\r<p>If the returned merchandise involves layaway, the 25% deposit is not refundable. The returned merchandise must be accompanied by proof of purchase and the original copy of the warranty as well as all original documentation and packaging; otherwise, the return will not be honored. \r\r<p>You must obtain a Return Merchandise Authorization (RMA) number from [store_name] before returning merchandise. We will not accept any returned merchandise without an RMA number. <a href=\"contact_us.php\">Contact customer service</a> to obtain an RMA number. \"New and unused\" means that there are no scratches, marks, or blemishes on the item; the security tags are still attached; and the item must not have been sized or altered in any way. We cannot accept a return of any item with any indication that it has been used.\r\r<p>For returning an item to [store_name]: \r\r<p><a href=\"contact_us.php\">Contact customer service</a> to obtain an RMA number. The RMA number must be written on the original invoice.\r\r<p>Repack the product in its original packaging materials, including warranties. Ship your return prepaid and insured for the full purchase price by a carrier that offers package tracking such as United Parcel Service (UPS) or Federal Express to the address listed at the top of the invoice. \r\r<p>If you receive a damaged or incorrect item, <a href=\"contact_us.php\">contact customer service</a> no later than 5 business days of receipt.  On a case by case basis, we will cover shipping charges up to a maximum of $12.00 upon our receipt of the defective or mis-delivered item.  If there is extensive damage to the carton, refuse the order and <a href=\"contact_us.php\">contact customer service</a> immediately.',1);
INSERT INTO information_documents VALUES (15,4,1,'Order Status','You can check the status of your orders by accessing your account online 24 hours a day. All you need is your Email address and password. If you have forgotten your password you can request that it be Emailed to you automatically from the login page.',1);
INSERT INTO information_documents VALUES (16,4,1,'Payment Options','[store_name] gladly accepts payments for purchases in the form of credit card, personal check, money order, cashier\'s check or certified bank check. \r\r<p><b>Credit Card </b>\r\r<p>[store_name] accepts the following credit cards for payment: \r\r<p>Visa \r<br />MasterCard \r<br />Discover \r<br />American Express \r\r<p>Some orders may require a credit card authorization form to be completed and returned. Click here for authorization form.\r\r<p><b> Checks</b>\r\r<p>[store_name] accepts personal checks for electronic processing on phone orders only at no additional charge to you. Your check must be drawn on a U.S. bank account. \"Temporary\" or counter checks are not acceptable. \r\r<p>Standard Written Check and Money Orders (sent through the mail). [store_name] also accepts personal checks, money orders, cashier\'s checks, or certified bank checks denominated in U.S. dollars as payment for all orders. Checks must be drawn on a U.S. bank and have the customer\'s name and address imprinted on the check front, with a valid nine-digit bank routing number (ABA code) located at the bottom of the check. \"Temporary\" or counter checks are not acceptable. Please make your check payable to [store_name]. and mail to: \r\r<p>[store_address] \r\r<p>Please Note: \r\r<p>If you pay by personal check, money order, cashier\'s check, or certified bank check, your order will be delayed since we must wait for receipt of the check and for the funds to clear before we can ship your merchandise. If you reside in [store_country], paying by any of the above methods typically delays your order about 15 business days from the day we receive your check. Dishonored checks will be assessed a fee of $20.00 or the maximum allowed by law.',1);
INSERT INTO information_documents VALUES (17,4,1,'Secure Shopping','We use the industry standard encryption protocol known as Secure Socket Layer (SSL) to keep your order information secure. \r\r<p>We have established a Secure Shopping Guarantee for every transaction that you make with [store_name]. Should any unauthorized charges appear on your credit card as a result of shopping with [store_name], you must notify your credit card provider in accordance with its reporting rules and procedures. \r\r<p>We will cover the liability of purchases made through this web site only if the unauthorized use of your credit card resulted through no fault of your own. If your bank holds you responsible for fraudulent charges, we will cover your liability up to $50.00.',1);
INSERT INTO information_documents VALUES (18,4,1,'Terms &amp; Conditions','[store_name] DOES NOT WARRANT THAT INFORMATION CONTAINED ON THE SITE WILL BE ACCURATE, RELIABLE OR ERROR FREE, OR THAT DEFECTS WILL BE CORRECTED. [store_name] CANNOT BE HELD RESPONSIBLE FOR ERRORS AND OMISSIONS IN THE SITE AND RESERVES THE RIGHT TO MODIFY AND CORRECT ERRORS AT ANY TIME. MATERIAL ON THE SITE MAY ALSO CONTAIN TECHNICAL INACCURACIES OR TYPOGRAPHICAL ERRORS (INCLUDING PRICING ERRORS), AND MAY BE CHANGED, UPDATED OR MODIFIED AT ANY TIME AND FROM TIME TO TIME WITHOUT NOTICE; [store_name] WILL NOT BE LIABLE OR RESPONSIBLE FOR ANY SUCH INACCURACIES, ERRORS, CHANGES, OR UPDATES. [store_name] MAY IN ITS SOLE DISCRETION ADD, DELETE, OR CHANGE SOME OR ALL OF ITS PRODUCTS AND SERVICES AT ANY TIME. [store_name] has attempted to accurately depict the products offered on the Site. However, because the depiction of a product is dependent on your computer monitor, [store_name] cannot guarantee that such depiction will be accurate. The products also may appear larger or smaller than their actual size depending on your monitor. Some photographs have been enlarged to show detail. \r\r<p>USE OF THE SITE IS ENTIRELY AT YOUR OWN RISK. EXCEPT AS EXPRESSLY SET FORTH BELOW OR IN A WRITTEN WARRANTY THAT ACCOMPANIES A PRODUCT (AND THEN ONLY WITH RESPECT TO SUCH PRODUCT), [store_name] EXPRESSLY DISCLAIMS ALL REPRESENTATIONS AND WARRANTIES OF ANY KIND EITHER EXPRESS OR IMPLIED (INCLUDING WITHOUT LIMITATION, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, ACCURACY AND AVAILABILITY) REGARDING THE SITE AND ANY PRODUCTS OFFERED OR AVAILABLE THROUGH THE SITE. THE SITE AND PRODUCTS AND INFORMATION ON THE SITE ARE PROVIDED ON AN \'AS IS-WHERE IS\' BASIS. NEITHER [store_name] NOR ITS SUBSIDIARIES, AFFILIATES OR ANY OF THEIR RESPECTIVE EMPLOYEES, AGENTS, DIRECTORS, EMPLOYEES, REPRESENTATIVES, SHAREHOLDERS, PREDECESSORS, SUCCESSORS, OR ASSIGNS (COLLECTIVELY, \'AFFILIATES\') WILL BE LIABLE FOR ANY INDIRECT, INCIDENTAL, SPECIAL, PUNITIVE, OR CONSEQUENTIAL DAMAGES WHATSOEVER ARISING DIRECTLY OR INDIRECTLY FROM USE OF THE SITE, THE INFORMATION CONTAINED ON OR TRANSMITTED FROM THE SITE OR PRODUCTS AVAILABLE OR PURCHASED THROUGH THE SITE, OR TRANSACTIONS CONDUCTED AT THE SITE, EVEN IF [store_name] HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES OR LOSSES. SOME STATES DO NOT ALLOW THE EXCLUSION OR LIMITATION OF LIABILITY FOR CONSEQUENTIAL OR INCIDENTAL DAMAGES SO THE ABOVE LIMITATION OR EXCLUSION MAY NOT APPLY TO YOU. IN NO EVENT SHALL THE TOTAL LIABILITY OF [store_name] OR ITS AFFILIATES ARISING DIRECTLY OR INDIRECTLY FROM THIS SITE OR ANY PRODUCTS AVAILABLE OR PURCHASED THROUGH THE SITE EXCEED THE LESSER OF THE AMOUNT PAID BY YOU TO [store_name] FOR THE SINGLE PRODUCT AT ISSUE, OR ONE THOUSAND DOLLARS ($1,000). YOU HEREBY ACKNOWLEDGE THAT ALL THE PROVISIONS OF THIS SECTION WILL APPLY TO ALL USE OF THE SITE, THE INFORMATION CONTAINED ON THE SITE, AND PRODUCTS AVAILABLE OR PURCHASED THROUGH THE SITE, AND TRANSACTIONS CONDUCTED AT THE SITE. \r\r<p>Subject to the following arbitration provision these terms and conditions shall be governed by, construed and interpreted according to the laws of the State of [store_zone], and you and [store_name] (the \'Parties\') agree to and consent to the exclusive jurisdiction and venue of the courts in OurCounty, [store_zone]. Should a dispute arise between the Parties which cannot be resolved by the Parties in good faith negotiations, both Parties agree to submit such dispute to arbitration in [store_zone], before a single arbitrator familiar with the Uniform Commercial Code using the Commercial Rules of the American Arbitration Association, with the following modifications to be enforced by the arbitrator consistent with [store_zone] law:\r\r<p>(a) any such arbitration proceeding shall be confidential as to the existence, content, and results of the arbitration;\r\r<p>(b) depositions shall not exceed two (2) per party and all must be completed within a single day;\r\r<p>(c) document requests are limited to no more than ten (10) clearly identified categories of documents which must be provided to the requesting party within five (5) business days of the request;\r\r<p>(d) each party shall have no more than eight (8) hours to present its position; and\r\r<p>(e) the entire hearing shall last no longer than three (3) business days.\r\r<p>The award, if any, shall be rendered no more than thirty (30) days following the end of the proceeding. Judgment upon the award rendered by the arbitrator may be entered by any court having jurisdiction. Both Parties expressly agree that any such controversy or claim shall be arbitrated on an individual basis, and shall not be consolidated in any arbitration with any claim or controversy of any other party. Each party shall bear its own attorneys\' fees and costs in connection with the proceedings and shall share equally the fees and expenses of the arbitrator.\r<br />',1);
INSERT INTO information_documents VALUES (19,5,1,'Sales Tax','Since [store_name] is based in [store_zone], state law requires that we charge sales tax on orders shipped to customers residing in [store_zone]. \r\r<p>To customers residing in states other than [store_zone], please be aware that, if applicable, the taxing authorities in your state may charge you a \"use\" tax on your out-of-state internet and/or catalog purchases. While it is not the responsibility of [store_name] to charge or collect this \"use\" tax from you at this time, we are alerting our customers regarding this possibility as a courtesy. If you require further information on this issue, we suggest you contact the tax authorities in your state directly.',1);
INSERT INTO information_documents VALUES (20,5,1,'Same Day Shipping','In-Stock Items \r\r<p>Most orders for In-Stock items begin the order process as soon as your online purchase is completed.\r\r<p>[store_name] offers same day shipping on many orders for in-stock merchandise if we receive and process your credit card order before 3:00 pm PST Monday through Friday. Credit card orders for in-stock merchandise received after 3:00 p.m. PST Friday, on a weekend day or a holiday will begin processing the next business day. \r\r<p>Merchandise not available for same day shipping usually ships within two business days after your credit card order has processed.  Please note that overnight delivery on credit card orders for in-stock merchandise processed before 3:00 p.m. PST on Fridays will be shipped on Monday as the next business day unless you select Saturday delivery for an additional charge when available. Please consult with your Sales Associate for details. ',1);
INSERT INTO information_documents VALUES (21,5,1,'Shipping Rules &amp; Restrictions','Most orders begin the order process as soon as your online purchase is completed. Your order will be shipped once your payment is approved, the receiving address is verified, and the item is located in stock. If an item you order is not currently in stock, you will be notified by Email. \r\r<p>For security reasons, all shipments over $200 require an authorized signature*.  If you cannot be available to sign for your package, please be sure that an adult who is authorized to sign for your package will be present at the designated shipping address. \r\r<p>*Important note: If your order is being delivered to an office building, apartment complex or similar facility, or to a public institution such as a hospital, hotel, school, etc., the carrier may accept the signatures of mailroom employees, receptionists, and similar administrative personnel upon delivery. Upon signature or acceptance by such personnel, we shall be deemed to have fulfilled our entire delivery obligation for your order. We are not responsible for lost or stolen items delivered in accordance with the delivery practices noted above.',1);
INSERT INTO information_documents VALUES (22,5,1,'Shipping Choices &amp; Costs','U.S. Shipments \r\r<p>[store_name] is proud to offer FREE ground shipping on all orders totaling at least $150 (excluding taxes and shipping &amp; handling charges) to all U.S. destinations except Alaska and Hawaii; shipments to Alaska and Hawaii can only be shipped by 2nd day or Next Day service. All orders are shipped using UPS or FedEx and are fully insured in transit. Delivery time is usually five (5) business days from the time your package leaves our warehouse. Please note that we cannot ship to P.O. Boxes. \r\r<p>For your security, your order will not be delivered without an authorized signature.\r\r<p>If you cannot be available to sign for your package, please be sure that an adult who is authorized to sign for your package will be available at the designated shipping address.  Customers will be charged a fee of $10 to reroute a package once it has been released to our carriers. \r\r<p><b>International Shipments </b>\r\r<p>All prices and shipping charges are listed in U.S. currency. \r\r<p>[store_name] ships your packages via International Service at a flat rate of $29.95 per shipment; shipments to Canada and Puerto Rico are shipped at a flat rate of $24.95. You can place your international order at [store_name] vi<B>A</B>: \r\r<p>Please note: International orders are subject to additional handling charges, higher shipping rates, and applicable customs, import duties and taxes, which are the sole responsibility of the customer. The customer will be charged for these fees prior to shipment. [store_name] uses best efforts to calculate these fees in advance as a convenience to our customers; however, any shortages in shipping, handling or customs duty fees after merchandise has shipped will be charged to the customer\'s credit card or invoiced to the customer and collected by the carrier at time of delivery (C.O.D.). These fees are non-refundable in the event the merchandise is returned to [store_name] for any reason. \r\r<p>Since customs policies vary widely from country to country, we urge our international customers to contact their local customs office for further information.',1);

INSERT INTO information_panels VALUES (1,1,'FAQ','[navbar_info_faq]');
INSERT INTO information_panels VALUES (2,1,'Policies','[navbar_info_policies]');
INSERT INTO information_panels VALUES (3,1,'Returns &amp; Exchanges','[navbar_info_returns]');
INSERT INTO information_panels VALUES (4,1,'Secure Shopping','[navbar_info_shopping]');
INSERT INTO information_panels VALUES (5,1,'Shipping &amp; Taxes','[navbar_info_shiptax]');

INSERT INTO languages VALUES (1,'English (US)','en','en_US.gif');

INSERT INTO orders_status_values VALUES (1, 1, 'New', 'new', '1', 1);
INSERT INTO orders_status_values VALUES (2, 1, 'Processing', 'processing', '1', 2);
INSERT INTO orders_status_values VALUES (3, 1, 'Shipped', 'intransit', '0', 3);
INSERT INTO orders_status_values VALUES (4, 1, 'Delivered', 'delivered', '0', 4);
INSERT INTO orders_status_values VALUES (5, 1, 'Cancelled', 'terminated', '0', 5);

INSERT INTO tax_class VALUES (1,'Taxable Items','The following types of products are included non-food, services,',now(),now());

INSERT INTO tax_rates VALUES (1,1,1,8.25,'California Sales Tax',now(),now());

INSERT INTO zones VALUES (1,223,'AL','Alabama');
INSERT INTO zones VALUES (2,223,'AK','Alaska');
INSERT INTO zones VALUES (3,223,'AS','American Samoa');
INSERT INTO zones VALUES (4,223,'AZ','Arizona');
INSERT INTO zones VALUES (5,223,'AR','Arkansas');
INSERT INTO zones VALUES (6,223,'AF','Armed Forces Africa');
INSERT INTO zones VALUES (7,223,'AA','Armed Forces Americas');
INSERT INTO zones VALUES (8,223,'AC','Armed Forces Canada');
INSERT INTO zones VALUES (9,223,'AE','Armed Forces Europe');
INSERT INTO zones VALUES (10,223,'AM','Armed Forces Middle East');
INSERT INTO zones VALUES (11,223,'AP','Armed Forces Pacific');
INSERT INTO zones VALUES (12,223,'CA','California');
INSERT INTO zones VALUES (13,223,'CO','Colorado');
INSERT INTO zones VALUES (14,223,'CT','Connecticut');
INSERT INTO zones VALUES (15,223,'DE','Delaware');
INSERT INTO zones VALUES (16,223,'DC','District of Columbia');
INSERT INTO zones VALUES (17,223,'FM','Federated States Of Micronesia');
INSERT INTO zones VALUES (18,223,'FL','Florida');
INSERT INTO zones VALUES (19,223,'GA','Georgia');
INSERT INTO zones VALUES (20,223,'GU','Guam');
INSERT INTO zones VALUES (21,223,'HI','Hawaii');
INSERT INTO zones VALUES (22,223,'ID','Idaho');
INSERT INTO zones VALUES (23,223,'IL','Illinois');
INSERT INTO zones VALUES (24,223,'IN','Indiana');
INSERT INTO zones VALUES (25,223,'IA','Iowa');
INSERT INTO zones VALUES (26,223,'KS','Kansas');
INSERT INTO zones VALUES (27,223,'KY','Kentucky');
INSERT INTO zones VALUES (28,223,'LA','Louisiana');
INSERT INTO zones VALUES (29,223,'ME','Maine');
INSERT INTO zones VALUES (30,223,'MH','Marshall Islands');
INSERT INTO zones VALUES (31,223,'MD','Maryland');
INSERT INTO zones VALUES (32,223,'MA','Massachusetts');
INSERT INTO zones VALUES (33,223,'MI','Michigan');
INSERT INTO zones VALUES (34,223,'MN','Minnesota');
INSERT INTO zones VALUES (35,223,'MS','Mississippi');
INSERT INTO zones VALUES (36,223,'MO','Missouri');
INSERT INTO zones VALUES (37,223,'MT','Montana');
INSERT INTO zones VALUES (38,223,'NE','Nebraska');
INSERT INTO zones VALUES (39,223,'NV','Nevada');
INSERT INTO zones VALUES (40,223,'NH','New Hampshire');
INSERT INTO zones VALUES (41,223,'NJ','New Jersey');
INSERT INTO zones VALUES (42,223,'NM','New Mexico');
INSERT INTO zones VALUES (43,223,'NY','New York');
INSERT INTO zones VALUES (44,223,'NC','North Carolina');
INSERT INTO zones VALUES (45,223,'ND','North Dakota');
INSERT INTO zones VALUES (46,223,'MP','Northern Mariana Islands');
INSERT INTO zones VALUES (47,223,'OH','Ohio');
INSERT INTO zones VALUES (48,223,'OK','Oklahoma');
INSERT INTO zones VALUES (49,223,'OR','Oregon');
INSERT INTO zones VALUES (50,223,'PW','Palau');
INSERT INTO zones VALUES (51,223,'PA','Pennsylvania');
INSERT INTO zones VALUES (52,223,'PR','Puerto Rico');
INSERT INTO zones VALUES (53,223,'RI','Rhode Island');
INSERT INTO zones VALUES (54,223,'SC','South Carolina');
INSERT INTO zones VALUES (55,223,'SD','South Dakota');
INSERT INTO zones VALUES (56,223,'TN','Tennessee');
INSERT INTO zones VALUES (57,223,'TX','Texas');
INSERT INTO zones VALUES (58,223,'UT','Utah');
INSERT INTO zones VALUES (59,223,'VT','Vermont');
INSERT INTO zones VALUES (60,223,'VI','Virgin Islands');
INSERT INTO zones VALUES (61,223,'VA','Virginia');
INSERT INTO zones VALUES (62,223,'WA','Washington');
INSERT INTO zones VALUES (63,223,'WV','West Virginia');
INSERT INTO zones VALUES (64,223,'WI','Wisconsin');
INSERT INTO zones VALUES (65,223,'WY','Wyoming');
INSERT INTO zones VALUES (66,38,'AB','Alberta');
INSERT INTO zones VALUES (67,38,'BC','British Columbia');
INSERT INTO zones VALUES (68,38,'MB','Manitoba');
INSERT INTO zones VALUES (69,38,'NF','Newfoundland');
INSERT INTO zones VALUES (70,38,'NB','New Brunswick');
INSERT INTO zones VALUES (71,38,'NS','Nova Scotia');
INSERT INTO zones VALUES (72,38,'NT','Northwest Territories');
INSERT INTO zones VALUES (73,38,'NU','Nunavut');
INSERT INTO zones VALUES (74,38,'ON','Ontario');
INSERT INTO zones VALUES (75,38,'PE','Prince Edward Island');
INSERT INTO zones VALUES (76,38,'QC','Quebec');
INSERT INTO zones VALUES (77,38,'SK','Saskatchewan');
INSERT INTO zones VALUES (78,38,'YT','Yukon Territory');
INSERT INTO zones VALUES (79,81,'NDS','Niedersachsen');
INSERT INTO zones VALUES (80,81,'BAW','Baden-Württemberg');
INSERT INTO zones VALUES (81,81,'BAY','Bayern');
INSERT INTO zones VALUES (82,81,'BER','Berlin');
INSERT INTO zones VALUES (83,81,'BRG','Brandenburg');
INSERT INTO zones VALUES (84,81,'BRE','Bremen');
INSERT INTO zones VALUES (85,81,'HAM','Hamburg');
INSERT INTO zones VALUES (86,81,'HES','Hessen');
INSERT INTO zones VALUES (87,81,'MEC','Mecklenburg-Vorpommern');
INSERT INTO zones VALUES (88,81,'NRW','Nordrhein-Westfalen');
INSERT INTO zones VALUES (89,81,'RHE','Rheinland-Pfalz');
INSERT INTO zones VALUES (90,81,'SAR','Saarland');
INSERT INTO zones VALUES (91,81,'SAS','Sachsen');
INSERT INTO zones VALUES (92,81,'SAC','Sachsen-Anhalt');
INSERT INTO zones VALUES (93,81,'SCN','Schleswig-Holstein');
INSERT INTO zones VALUES (94,81,'THE','Thüringen');
INSERT INTO zones VALUES (95,14,'WI','Wien');
INSERT INTO zones VALUES (96,14,'NO','Niederösterreich');
INSERT INTO zones VALUES (97,14,'OO','Oberösterreich');
INSERT INTO zones VALUES (98,14,'SB','Salzburg');
INSERT INTO zones VALUES (99,14,'KN','Kärnten');
INSERT INTO zones VALUES (100,14,'ST','Steiermark');
INSERT INTO zones VALUES (101,14,'TI','Tirol');
INSERT INTO zones VALUES (102,14,'BL','Burgenland');
INSERT INTO zones VALUES (103,14,'VB','Voralberg');
INSERT INTO zones VALUES (130,195,'Alava','Alava');
INSERT INTO zones VALUES (131,195,'Malaga','Malaga');
INSERT INTO zones VALUES (132,195,'Segovia','Segovia');
INSERT INTO zones VALUES (133,195,'Granada','Granada');
INSERT INTO zones VALUES (134,195,'Jaen','Jaen');
INSERT INTO zones VALUES (135,195,'Sevilla','Sevilla');
INSERT INTO zones VALUES (136,195,'Barcelona','Barcelona');
INSERT INTO zones VALUES (137,195,'Valencia','Valencia');
INSERT INTO zones VALUES (138,195,'Alicante','Alicante');
INSERT INTO zones VALUES (139,195,'Almeria','Almeria');
INSERT INTO zones VALUES (140,195,'Asturias','Asturias');
INSERT INTO zones VALUES (141,195,'Avila','Avila');
INSERT INTO zones VALUES (142,195,'Badajoz','Badajoz');
INSERT INTO zones VALUES (143,195,'Burgos','Burgos');
INSERT INTO zones VALUES (144,195,'Caceres','Caceres');
INSERT INTO zones VALUES (145,195,'Cadiz','Cadiz');
INSERT INTO zones VALUES (146,195,'Cantabria','Cantabria');
INSERT INTO zones VALUES (147,195,'Castellon','Castellon');
INSERT INTO zones VALUES (148,195,'Ceuta','Ceuta');
INSERT INTO zones VALUES (149,195,'Ciudad Real','Ciudad Real');
INSERT INTO zones VALUES (150,195,'Cordoba','Cordoba');
INSERT INTO zones VALUES (151,195,'Cuenca','Cuenca');
INSERT INTO zones VALUES (152,195,'Girona','Girona');
INSERT INTO zones VALUES (153,195,'Las Palmas','Las Palmas');
INSERT INTO zones VALUES (154,195,'Guadalajara','Guadalajara');
INSERT INTO zones VALUES (155,195,'Guipuzcoa','Guipuzcoa');
INSERT INTO zones VALUES (156,195,'Huelva','Huelva');
INSERT INTO zones VALUES (157,195,'Huesca','Huesca');
INSERT INTO zones VALUES (158,195,'A Coru a','A Coru a');
INSERT INTO zones VALUES (159,195,'La Rioja','La Rioja');
INSERT INTO zones VALUES (160,195,'Leon','Leon');
INSERT INTO zones VALUES (161,195,'Lugo','Lugo');
INSERT INTO zones VALUES (162,195,'Lleida','Lleida');
INSERT INTO zones VALUES (163,195,'Madrid','Madrid');
INSERT INTO zones VALUES (164,195,'Baleares','Baleares');
INSERT INTO zones VALUES (165,195,'Cantabria','Cantabria');
INSERT INTO zones VALUES (166,195,'Murcia','Murcia');
INSERT INTO zones VALUES (167,195,'Navarra','Navarra');
INSERT INTO zones VALUES (168,195,'Ourense','Ourense');
INSERT INTO zones VALUES (169,195,'Palencia','Palencia');
INSERT INTO zones VALUES (170,195,'Pontevedra','Pontevedra');
INSERT INTO zones VALUES (171,195,'Salamanca','Salamanca');
INSERT INTO zones VALUES (172,195,'Soria','Soria');
INSERT INTO zones VALUES (173,195,'Tarragona','Tarragona');
INSERT INTO zones VALUES (174,195,'Tenerife','Tenerife');
INSERT INTO zones VALUES (175,195,'Teruel','Teruel');
INSERT INTO zones VALUES (176,195,'Toledo','Toledo');
INSERT INTO zones VALUES (177,195,'Valladolid','Valladolid');
INSERT INTO zones VALUES (178,195,'Vizcaya','Vizcaya');
INSERT INTO zones VALUES (179,195,'Zamora','Zamora');
INSERT INTO zones VALUES (180,195,'Zaragoza','Zaragoza');
INSERT INTO zones VALUES (181,195,'Melilla','Melilla');
INSERT INTO zones VALUES (190,13,'ACT','Australian Capital Territory');
INSERT INTO zones VALUES (191,13,'NSW','New South Wales');
INSERT INTO zones VALUES (192,13,'NT','Northern Territory');
INSERT INTO zones VALUES (193,13,'QLD','Queensland');
INSERT INTO zones VALUES (194,13,'SA','South Australia');
INSERT INTO zones VALUES (195,13,'TAS','Tasmania');
INSERT INTO zones VALUES (196,13,'VIC','Victoria');
INSERT INTO zones VALUES (197,13,'WA','Western Australia');
INSERT INTO zones VALUES (1448,138,'AGS','Aguascalientes');
INSERT INTO zones VALUES (1449,138,'BC','Baja California');
INSERT INTO zones VALUES (1450,138,'BCS','Baja California Sur');
INSERT INTO zones VALUES (1451,138,'CAM','Campeche');
INSERT INTO zones VALUES (1452,138,'COA','Coahuila');
INSERT INTO zones VALUES (1453,138,'COL','Colima');
INSERT INTO zones VALUES (1454,138,'CHI','Chiapas');
INSERT INTO zones VALUES (1455,138,'CHIH','Chihuahua');
INSERT INTO zones VALUES (1456,138,'DF','Distrito Federal');
INSERT INTO zones VALUES (1457,138,'DGO','Durango');
INSERT INTO zones VALUES (1458,138,'MEX','Estado de Mexico');
INSERT INTO zones VALUES (1459,138,'GTO','Guanajuato');
INSERT INTO zones VALUES (1460,138,'GRO','Guerrero');
INSERT INTO zones VALUES (1461,138,'HGO','Hidalgo');
INSERT INTO zones VALUES (1462,138,'JAL','Jalisco');
INSERT INTO zones VALUES (1463,138,'MCH','Michoacan');
INSERT INTO zones VALUES (1464,138,'MOR','Morelos');
INSERT INTO zones VALUES (1465,138,'NAY','Nayarit');
INSERT INTO zones VALUES (1466,138,'NL','Nuevo Leon');
INSERT INTO zones VALUES (1467,138,'OAX','Oaxaca');
INSERT INTO zones VALUES (1468,138,'PUE','Puebla');
INSERT INTO zones VALUES (1469,138,'QRO','Queretaro');
INSERT INTO zones VALUES (1470,138,'QR','Quintana Roo');
INSERT INTO zones VALUES (1471,138,'SLP','San Luis Potosi');
INSERT INTO zones VALUES (1472,138,'SIN','Sinaloa');
INSERT INTO zones VALUES (1473,138,'SON','Sonora');
INSERT INTO zones VALUES (1474,138,'TAB','Tabasco');
INSERT INTO zones VALUES (1475,138,'TMPS','Tamaulipas');
INSERT INTO zones VALUES (1476,138,'TLAX','Tlaxcala');
INSERT INTO zones VALUES (1477,138,'VER','Veracruz');
INSERT INTO zones VALUES (1478,138,'YUC','Yucatan');
INSERT INTO zones VALUES (1479,138,'ZAC','Zacatecas');
INSERT INTO zones VALUES (1480,193,'WP','Western Cape');
INSERT INTO zones VALUES (1481,193,'GP','Gauteng');
INSERT INTO zones VALUES (1482,193,'KZN','Kwazulu-Natal');
INSERT INTO zones VALUES (1483,193,'NC','Northern-Cape');
INSERT INTO zones VALUES (1484,193,'EC','Eastern-Cape');
INSERT INTO zones VALUES (1485,193,'MP','Mpumalanga');
INSERT INTO zones VALUES (1486,193,'NW','North-West');
INSERT INTO zones VALUES (1487,193,'FS','Free State');
INSERT INTO zones VALUES (1488,193,'NP','Northern Province');
INSERT INTO zones VALUES (1489,204,'AG','Argovie/Aargau');
INSERT INTO zones VALUES (1490,204,'AI','Appenzell Rhode intérieur/Inne');
INSERT INTO zones VALUES (1491,204,'AR','Appenzell Rhode extérieur/Auss');
INSERT INTO zones VALUES (1492,204,'BE','Berne/Bern');
INSERT INTO zones VALUES (1493,204,'BL','Bales-Campagne/Basel-Landschaft');
INSERT INTO zones VALUES (1494,204,'BS','Bales-Ville/Basel-Stadt');
INSERT INTO zones VALUES (1495,204,'FR','Fribourg/Freiburg');
INSERT INTO zones VALUES (1496,204,'GE','Genève/Genf');
INSERT INTO zones VALUES (1497,204,'GL','Glaris/Glarus');
INSERT INTO zones VALUES (1498,204,'JU','Grisons/Graubünden');
INSERT INTO zones VALUES (1499,204,'JU','Jura');
INSERT INTO zones VALUES (1500,204,'LU','Lucerne/Luzern');
INSERT INTO zones VALUES (1501,204,'NE','Neuchâtel/Neuenburg');
INSERT INTO zones VALUES (1502,204,'NW','Nidwald/Nidwalden');
INSERT INTO zones VALUES (1503,204,'OW','Obwald/Obwalden');
INSERT INTO zones VALUES (1504,204,'SG','St.Galles/St. Gallen');
INSERT INTO zones VALUES (1505,204,'SH','Schaffouse/Schaffhausen');
INSERT INTO zones VALUES (1506,204,'SO','Soleure/Solothurn');
INSERT INTO zones VALUES (1507,204,'SZ','Schwyz');
INSERT INTO zones VALUES (1508,204,'TG','Turgovie/Thurgau');
INSERT INTO zones VALUES (1509,204,'TI','Tessin');
INSERT INTO zones VALUES (1510,204,'UR','Uri');
INSERT INTO zones VALUES (1511,204,'VD','Vaud/Waadt');
INSERT INTO zones VALUES (1512,204,'VS','Valais/Wallis');
INSERT INTO zones VALUES (1513,204,'ZG','Zug');
INSERT INTO zones VALUES (1514,204,'ZH','Zürich');
INSERT INTO zones VALUES (1515,222,'ALD','Alderney');
INSERT INTO zones VALUES (1516,222,'ATM','County Antrim');
INSERT INTO zones VALUES (1517,222,'ARM','County Armagh');
INSERT INTO zones VALUES (1518,222,'AVN','Avon');
INSERT INTO zones VALUES (1519,222,'BFD','Bedfordshire');
INSERT INTO zones VALUES (1520,222,'BRK','Berkshire');
INSERT INTO zones VALUES (1521,222,'BDS','Borders');
INSERT INTO zones VALUES (1522,222,'BUX','Buckinghamshire');
INSERT INTO zones VALUES (1523,222,'CBE','Cambridgeshire');
INSERT INTO zones VALUES (1524,222,'CTR','Central');
INSERT INTO zones VALUES (1525,222,'CHS','Cheshire');
INSERT INTO zones VALUES (1526,222,'CVE','Cleveland');
INSERT INTO zones VALUES (1527,222,'CLD','Clwyd');
INSERT INTO zones VALUES (1528,222,'CNL','Cornwall');
INSERT INTO zones VALUES (1529,222,'CBA','Cumbria');
INSERT INTO zones VALUES (1530,222,'DYS','Derbyshire');
INSERT INTO zones VALUES (1531,222,'DVN','Devon');
INSERT INTO zones VALUES (1532,222,'DOR','Dorse');
INSERT INTO zones VALUES (1533,222,'DWN','County Down');
INSERT INTO zones VALUES (1534,222,'DGL','Dumfries and Galloway');
INSERT INTO zones VALUES (1535,222,'DHM','County Durham');
INSERT INTO zones VALUES (1536,222,'DFD','Dyfed');
INSERT INTO zones VALUES (1537,222,'ESX','Essex');
INSERT INTO zones VALUES (1538,222,'FMH','County Fermanagh');
INSERT INTO zones VALUES (1539,222,'FFE','Fife');
INSERT INTO zones VALUES (1540,222,'GNM','Mid Glamorgan');
INSERT INTO zones VALUES (1541,222,'GNS','South Glamorgan');
INSERT INTO zones VALUES (1542,222,'GNW','West Glamorgan');
INSERT INTO zones VALUES (1543,222,'GLR','Gloucester');
INSERT INTO zones VALUES (1544,222,'GRN','Grampian');
INSERT INTO zones VALUES (1545,222,'GUR','Guernsey');
INSERT INTO zones VALUES (1546,222,'GWT','Gwent');
INSERT INTO zones VALUES (1547,222,'GDD','Gwynedd');
INSERT INTO zones VALUES (1548,222,'HPH','Hampshire');
INSERT INTO zones VALUES (1549,222,'HWR','Hereford and Worcester');
INSERT INTO zones VALUES (1550,222,'HFD','Hertfordshire');
INSERT INTO zones VALUES (1551,222,'HLD','Highlands');
INSERT INTO zones VALUES (1552,222,'HBS','Humberside');
INSERT INTO zones VALUES (1553,222,'IOM','Isle of Man');
INSERT INTO zones VALUES (1554,222,'IOW','Isle of Wight');
INSERT INTO zones VALUES (1555,222,'JER','Jersey');
INSERT INTO zones VALUES (1556,222,'KNT','Kent');
INSERT INTO zones VALUES (1557,222,'LNH','Lancashire');
INSERT INTO zones VALUES (1558,222,'LEC','Leicestershire');
INSERT INTO zones VALUES (1559,222,'LCN','Lincolnshire');
INSERT INTO zones VALUES (1560,222,'LDN','Greater London');
INSERT INTO zones VALUES (1561,222,'LDR','County Londonderry');
INSERT INTO zones VALUES (1562,222,'LTH','Lothian');
INSERT INTO zones VALUES (1563,222,'MCH','Greater Manchester');
INSERT INTO zones VALUES (1564,222,'MSY','Merseyside');
INSERT INTO zones VALUES (1565,222,'NOR','Norfolk');
INSERT INTO zones VALUES (1566,222,'NHM','Northamptonshire');
INSERT INTO zones VALUES (1567,222,'NLD','Northumberland');
INSERT INTO zones VALUES (1568,222,'NOT','Nottinghamshire');
INSERT INTO zones VALUES (1569,222,'ORK','Orkney');
INSERT INTO zones VALUES (1570,222,'OFE','Oxfordshire');
INSERT INTO zones VALUES (1571,222,'PWS','Powys');
INSERT INTO zones VALUES (1572,222,'SPE','Shropshire');
INSERT INTO zones VALUES (1573,222,'SRK','Sark');
INSERT INTO zones VALUES (1574,222,'SLD','Shetland');
INSERT INTO zones VALUES (1575,222,'SOM','Somerset');
INSERT INTO zones VALUES (1576,222,'SFD','Staffordshire');
INSERT INTO zones VALUES (1577,222,'SCD','Strathclyde');
INSERT INTO zones VALUES (1578,222,'SFK','Suffolk');
INSERT INTO zones VALUES (1579,222,'SRY','Surrey');
INSERT INTO zones VALUES (1580,222,'SXE','East Sussex');
INSERT INTO zones VALUES (1581,222,'SXW','West Sussex');
INSERT INTO zones VALUES (1582,222,'TYS','Tayside');
INSERT INTO zones VALUES (1583,222,'TWR','Tyne and Wear');
INSERT INTO zones VALUES (1584,222,'TYR','County Tyrone');
INSERT INTO zones VALUES (1585,222,'WKS','Warwickshire');
INSERT INTO zones VALUES (1586,222,'WIL','Western Isles');
INSERT INTO zones VALUES (1587,222,'WMD','West Midlands');
INSERT INTO zones VALUES (1588,222,'WLT','Wiltshire');
INSERT INTO zones VALUES (1589,222,'YSN','North Yorkshire');
INSERT INTO zones VALUES (1590,222,'YSS','South Yorkshire');
INSERT INTO zones VALUES (1591,222,'YSW','West Yorkshire');
INSERT INTO zones VALUES (1592,30,'AC','Acre');
INSERT INTO zones VALUES (1593,30,'AL','Alagoas');
INSERT INTO zones VALUES (1594,30,'AM','Amazùnia');
INSERT INTO zones VALUES (1596,30,'AP','Amapá');
INSERT INTO zones VALUES (1597,30,'BA','Bahia');
INSERT INTO zones VALUES (1599,30,'CE','Cearã');
INSERT INTO zones VALUES (1600,30,'DF','Distrito Federal');
INSERT INTO zones VALUES (1601,30,'ES','Espìrito Santo');
INSERT INTO zones VALUES (1602,30,'GO','Goìas');
INSERT INTO zones VALUES (1603,30,'MA','Maranhão');
INSERT INTO zones VALUES (1604,30,'MG','Minas Gerais');
INSERT INTO zones VALUES (1605,30,'MS','Mato Grosso do Sul');
INSERT INTO zones VALUES (1606,30,'MT','Mato Grosso');
INSERT INTO zones VALUES (1607,30,'PA','Pará');
INSERT INTO zones VALUES (1608,30,'PB','Paraìba');
INSERT INTO zones VALUES (1609,30,'PE','Pernambuco');
INSERT INTO zones VALUES (1610,30,'PI','Piauì');
INSERT INTO zones VALUES (1612,30,'PR','Paranã');
INSERT INTO zones VALUES (1613,30,'RJ','Rio de Janeiro');
INSERT INTO zones VALUES (1614,30,'RN','Rio Grande do Norte');
INSERT INTO zones VALUES (1615,30,'RO','Roraima');
INSERT INTO zones VALUES (1616,30,'RR','Rondùnia');
INSERT INTO zones VALUES (1617,30,'RS','Rio Grande do Sul');
INSERT INTO zones VALUES (1618,30,'SC','Santa Catarina');
INSERT INTO zones VALUES (1619,30,'SE','Sergipe');
INSERT INTO zones VALUES (1620,30,'SP','Sao Paulo');
INSERT INTO zones VALUES (1621,30,'TO','Tocantins');
INSERT INTO zones VALUES (1622,150,'Drenthe','Drenthe');
INSERT INTO zones VALUES (1623,150,'Flevoland','Flevoland');
INSERT INTO zones VALUES (1624,150,'Friesland','Friesland');
INSERT INTO zones VALUES (1625,150,'Gelderland','Gelderland');
INSERT INTO zones VALUES (1626,150,'Groningen','Groningen');
INSERT INTO zones VALUES (1627,150,'Limburg','Limburg');
INSERT INTO zones VALUES (1628,150,'Noord-Brabant','Noord-Brabant');
INSERT INTO zones VALUES (1629,150,'Noord-Holland','Noord-Holland');
INSERT INTO zones VALUES (1630,150,'Overijssel','Overijssel');
INSERT INTO zones VALUES (1631,150,'Utrecht','Utrecht');
INSERT INTO zones VALUES (1632,150,'Zeeland','Zeeland');
INSERT INTO zones VALUES (1633,150,'Zuid_Holland','Zuid_Holland');
INSERT INTO zones VALUES (1634,103,'Carlow','Carlow');
INSERT INTO zones VALUES (1635,103,'Cavan','Cavan');
INSERT INTO zones VALUES (1636,103,'Clare','Clare');
INSERT INTO zones VALUES (1637,103,'Cork','Cork');
INSERT INTO zones VALUES (1638,103,'Donegal','Donegal');
INSERT INTO zones VALUES (1639,103,'Dublin','Dublin');
INSERT INTO zones VALUES (1640,103,'Galway','Galway');
INSERT INTO zones VALUES (1641,103,'Kerry','Kerry');
INSERT INTO zones VALUES (1642,103,'Kildare','Kildare');
INSERT INTO zones VALUES (1643,103,'Kilkenny','Kilkenny');
INSERT INTO zones VALUES (1644,103,'Laois','Laois');
INSERT INTO zones VALUES (1645,103,'Leitrim','Leitrim');
INSERT INTO zones VALUES (1646,103,'Limerick','Limerick');
INSERT INTO zones VALUES (1647,103,'Longford','Longford');
INSERT INTO zones VALUES (1648,103,'Louth','Louth');
INSERT INTO zones VALUES (1649,103,'Mayo','Mayo');
INSERT INTO zones VALUES (1650,103,'Meath','Meath');
INSERT INTO zones VALUES (1651,103,'Monaghan','Monaghan');
INSERT INTO zones VALUES (1652,103,'Offaly','Offaly');
INSERT INTO zones VALUES (1653,103,'Roscommon','Roscommon');
INSERT INTO zones VALUES (1654,103,'Sligo','Sligo');
INSERT INTO zones VALUES (1655,103,'Tipperary','Tipperary');
INSERT INTO zones VALUES (1656,103,'Waterford','Waterford');
INSERT INTO zones VALUES (1657,103,'Westmeath','Westmeath');
INSERT INTO zones VALUES (1658,103,'Wexford','Wexford');
INSERT INTO zones VALUES (1659,103,'Wicklow','Wicklow');
INSERT INTO zones VALUES (1660,105,'AG','Agrigento');
INSERT INTO zones VALUES (1661,105,'AL','Alessandria');
INSERT INTO zones VALUES (1662,105,'AN','Ancona');
INSERT INTO zones VALUES (1663,105,'AO','Aosta');
INSERT INTO zones VALUES (1664,105,'AR','Arezzo');
INSERT INTO zones VALUES (1665,105,'AP','Ascoli Piceno');
INSERT INTO zones VALUES (1666,105,'AT','Asti');
INSERT INTO zones VALUES (1667,105,'AV','Avellino');
INSERT INTO zones VALUES (1668,105,'BA','Bari');
INSERT INTO zones VALUES (1669,105,'BL','Belluno');
INSERT INTO zones VALUES (1670,105,'BN','Benevento');
INSERT INTO zones VALUES (1671,105,'BG','Bergamo');
INSERT INTO zones VALUES (1672,105,'BI','Biella');
INSERT INTO zones VALUES (1673,105,'BO','Bologna');
INSERT INTO zones VALUES (1674,105,'BZ','Bolzano');
INSERT INTO zones VALUES (1675,105,'BS','Brescia');
INSERT INTO zones VALUES (1676,105,'BR','Brindisi');
INSERT INTO zones VALUES (1677,105,'CA','Cagliari');
INSERT INTO zones VALUES (1678,105,'CL','Caltanissetta');
INSERT INTO zones VALUES (1679,105,'CB','Campobasso');
INSERT INTO zones VALUES (1680,105,'CE','Caserta');
INSERT INTO zones VALUES (1681,105,'CT','Catania');
INSERT INTO zones VALUES (1682,105,'CZ','Catanzaro');
INSERT INTO zones VALUES (1683,105,'CH','Chieti');
INSERT INTO zones VALUES (1684,105,'CO','Como');
INSERT INTO zones VALUES (1685,105,'CS','Cosenza');
INSERT INTO zones VALUES (1686,105,'CR','Cremona');
INSERT INTO zones VALUES (1687,105,'KR','Crotone');
INSERT INTO zones VALUES (1688,105,'CN','Cuneo');
INSERT INTO zones VALUES (1689,105,'EN','Enna');
INSERT INTO zones VALUES (1690,105,'FE','Ferrara');
INSERT INTO zones VALUES (1691,105,'FI','Firenze');
INSERT INTO zones VALUES (1692,105,'FG','Foggia');
INSERT INTO zones VALUES (1693,105,'FO','Forl');
INSERT INTO zones VALUES (1694,105,'FR','Frosinone');
INSERT INTO zones VALUES (1695,105,'GE','Genova');
INSERT INTO zones VALUES (1696,105,'GO','Gorizia');
INSERT INTO zones VALUES (1697,105,'GR','Grosseto');
INSERT INTO zones VALUES (1698,105,'IM','Imperia');
INSERT INTO zones VALUES (1699,105,'IS','Isernia');
INSERT INTO zones VALUES (1700,105,'AQ','Aquila');
INSERT INTO zones VALUES (1701,105,'SP','La Spezia');
INSERT INTO zones VALUES (1702,105,'LT','Latina');
INSERT INTO zones VALUES (1703,105,'LE','Lecce');
INSERT INTO zones VALUES (1704,105,'LC','Lecco');
INSERT INTO zones VALUES (1705,105,'LI','Livorno');
INSERT INTO zones VALUES (1706,105,'LO','Lodi');
INSERT INTO zones VALUES (1707,105,'LU','Lucca');
INSERT INTO zones VALUES (1708,105,'MC','Macerata');
INSERT INTO zones VALUES (1709,105,'MN','Mantova');
INSERT INTO zones VALUES (1710,105,'MS','Massa-Carrara');
INSERT INTO zones VALUES (1711,105,'MT','Matera');
INSERT INTO zones VALUES (1712,105,'ME','Messina');
INSERT INTO zones VALUES (1713,105,'MI','Milano');
INSERT INTO zones VALUES (1714,105,'MO','Modena');
INSERT INTO zones VALUES (1715,105,'NA','Napoli');
INSERT INTO zones VALUES (1716,105,'NO','Novara');
INSERT INTO zones VALUES (1717,105,'NU','Nuoro');
INSERT INTO zones VALUES (1718,105,'OR','Oristano');
INSERT INTO zones VALUES (1719,105,'PD','Padova');
INSERT INTO zones VALUES (1720,105,'PA','Palermo');
INSERT INTO zones VALUES (1721,105,'PR','Parma');
INSERT INTO zones VALUES (1722,105,'PG','Perugia');
INSERT INTO zones VALUES (1723,105,'PV','Pavia');
INSERT INTO zones VALUES (1724,105,'PS','Pesaro e Urbino');
INSERT INTO zones VALUES (1725,105,'PE','Pescara');
INSERT INTO zones VALUES (1726,105,'PC','Piacenza');
INSERT INTO zones VALUES (1727,105,'PI','Pisa');
INSERT INTO zones VALUES (1728,105,'PT','Pistoia');
INSERT INTO zones VALUES (1729,105,'PN','Pordenone');
INSERT INTO zones VALUES (1730,105,'PZ','Potenza');
INSERT INTO zones VALUES (1731,105,'PO','Prato');
INSERT INTO zones VALUES (1732,105,'RG','Ragusa');
INSERT INTO zones VALUES (1733,105,'RA','Ravenna');
INSERT INTO zones VALUES (1734,105,'RC','Reggio di Calabria');
INSERT INTO zones VALUES (1735,105,'RE','Reggio Emilia');
INSERT INTO zones VALUES (1736,105,'RI','Rieti');
INSERT INTO zones VALUES (1737,105,'RN','Rimini');
INSERT INTO zones VALUES (1738,105,'RM','Roma');
INSERT INTO zones VALUES (1739,105,'RO','Rovigo');
INSERT INTO zones VALUES (1740,105,'SA','Salerno');
INSERT INTO zones VALUES (1741,105,'SS','Sassari');
INSERT INTO zones VALUES (1742,105,'SV','Savona');
INSERT INTO zones VALUES (1743,105,'SI','Siena');
INSERT INTO zones VALUES (1744,105,'SR','Siracusa');
INSERT INTO zones VALUES (1745,105,'SO','Sondrio');
INSERT INTO zones VALUES (1746,105,'TA','Taranto');
INSERT INTO zones VALUES (1747,105,'TE','Teramo');
INSERT INTO zones VALUES (1748,105,'TR','Terni');
INSERT INTO zones VALUES (1749,105,'TO','Torino');
INSERT INTO zones VALUES (1750,105,'TP','Trapani');
INSERT INTO zones VALUES (1751,105,'TN','Trento');
INSERT INTO zones VALUES (1752,105,'TV','Treviso');
INSERT INTO zones VALUES (1753,105,'TS','Trieste');
INSERT INTO zones VALUES (1754,105,'UD','Udine');
INSERT INTO zones VALUES (1755,105,'VA','Varese');
INSERT INTO zones VALUES (1756,105,'VE','Venezia');
INSERT INTO zones VALUES (1757,105,'VB','Verbania');
INSERT INTO zones VALUES (1758,105,'VC','Vercelli');
INSERT INTO zones VALUES (1759,105,'VR','Verona');
INSERT INTO zones VALUES (1760,105,'VV','Vibo Valentia');
INSERT INTO zones VALUES (1761,105,'VI','Vicenza');
INSERT INTO zones VALUES (1762,105,'VT','Viterbo');

INSERT INTO zones_to_geo_zones VALUES (1,223,12,1,now(),now());
